@@ -78,10 +78,23 @@ void bitrow_print(uint8_t const *bitrow, unsigned bit_len);
 void bitrow_debug(uint8_t const *bitrow, unsigned bit_len);
 
 /// Print the content of a bit row (byte buffer) to a string buffer.
-/// The output is always null-terminated, unless size is 0.
+///
+/// Write at most @p size - 1 characters,
+/// the output is always null-terminated, unless size is 0.
+///
+/// @param bitrow the row of bytes to print
+/// @param bit_len the number of bits in @p bitrow to print
+/// @param str an output string buffer of sufficient size
+/// @param size the size of @p str
+///
+/// @return the number of characters printed (not including the trailing `\0`).
 int bitrow_snprint(uint8_t const *bitrow, unsigned bit_len, char *str, unsigned size);
 
 /// Parse a string into a bitbuffer.
+///
+/// The (optionally "0x" prefixed) hex code is processed into a bitbuffer_t.
+/// Each row is optionally prefixed with a length enclosed in braces "{}" or
+/// separated with a slash "/" character. Whitespace is ignored.
 void bitbuffer_parse(bitbuffer_t *bits, const char *code);
 
 /// Search the specified row of the bitbuffer, starting from bit 'start', for
@@ -107,15 +120,27 @@ unsigned bitbuffer_manchester_decode(bitbuffer_t *inbuf, unsigned row, unsigned
 unsigned bitbuffer_differential_manchester_decode(bitbuffer_t *inbuf, unsigned row, unsigned start,
         bitbuffer_t *outbuf, unsigned max);
 
-/// Function to compare bitbuffer rows and count repetitions.
-int compare_rows(bitbuffer_t *bits, unsigned row_a, unsigned row_b);
+/// Compares two given rows of a bitbuffer.
+///
+/// If @p max_bits is greater than 0 then only up that many bits are compared.
+int bitbuffer_compare_rows(bitbuffer_t *bits, unsigned row_a, unsigned row_b, unsigned max_bits);
 
-unsigned count_repeats(bitbuffer_t *bits, unsigned row);
+/// Count the number of repeats of row at index @p row.
+///
+/// If @p max_bits is greater than 0 then only up that many bits are compared.
+/// The returned count will include the given row and will be at least 1.
+unsigned bitbuffer_count_repeats(bitbuffer_t *bits, unsigned row, unsigned max_bits);
 
-/// Find a repeated row that has a minimum count of bits.
-/// Return the row index or -1.
+/// Find a row repeated at least @p min_repeats times and with at least @p min_bits bits length,
+/// all bits in the repeats need to match.
+/// @return the row index or -1.
 int bitbuffer_find_repeated_row(bitbuffer_t *bits, unsigned min_repeats, unsigned min_bits);
 
+/// Find a row repeated at least @p min_repeats times and with at least @p min_bits bits length,
+/// a prefix of at most @p min_bits bits will be compared.
+/// @return the row index or -1.
+int bitbuffer_find_repeated_prefix(bitbuffer_t *bits, unsigned min_repeats, unsigned min_bits);
+
 /// Return a single bit from a bitrow at bit_idx position.
 static inline uint8_t bitrow_get_bit(uint8_t const *bitrow, unsigned bit_idx)
 {
