@@ -32,50 +32,51 @@ static int akhan_rke_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         return DECODE_ABORT_LENGTH;
     b = bitbuffer->bb[0];
 
-    //invert bits, short pulse is 0, long pulse is 1
+    // invert bits, short pulse is 0, long pulse is 1
     b[0] = ~b[0];
     b[1] = ~b[1];
     b[2] = ~b[2];
 
-    id = (b[0] << 12) | (b[1] << 4) | (b[2] >> 4);
+    id  = (b[0] << 12) | (b[1] << 4) | (b[2] >> 4);
     cmd = b[2] & 0x0F;
     switch (cmd) {
-        case 0x1: cmd_str = "0x1 (Lock)"; break;
-        case 0x2: cmd_str = "0x2 (Unlock)"; break;
-        case 0x4: cmd_str = "0x4 (Mute)"; break;
-        case 0x8: cmd_str = "0x8 (Alarm)"; break;
-        default:  cmd_str = NULL; break;
+    case 0x1: cmd_str = "0x1 (Lock)"; break;
+    case 0x2: cmd_str = "0x2 (Unlock)"; break;
+    case 0x4: cmd_str = "0x4 (Mute)"; break;
+    case 0x8: cmd_str = "0x8 (Alarm)"; break;
+    default: cmd_str = NULL; break;
     }
 
     if (!cmd_str)
         return DECODE_FAIL_SANITY;
 
+    /* clang-format off */
     data = data_make(
             "model",    "",             DATA_STRING, "Akhan-100F14",
             "id",       "ID (20bit)",   DATA_FORMAT, "0x%x", DATA_INT, id,
             "data",     "Data (4bit)",  DATA_STRING, cmd_str,
             NULL);
+    /* clang-format on */
 
     decoder_output_data(decoder, data);
     return 1;
 }
 
 static char *output_fields[] = {
-    "model",
-    "id",
-    "data",
-    NULL
+        "model",
+        "id",
+        "data",
+        NULL,
 };
 
 r_device akhan_100F14 = {
-    .name          = "Akhan 100F14 remote keyless entry",
-    .modulation    = OOK_PULSE_PWM,
-    .short_width   = 316,
-    .long_width    = 1020,
-    .reset_limit   = 1800,
-    .sync_width    = 0,
-    .tolerance     = 80, // us
-    .decode_fn     = &akhan_rke_callback,
-    .disabled      = 0,
-    .fields        = output_fields,
+        .name        = "Akhan 100F14 remote keyless entry",
+        .modulation  = OOK_PULSE_PWM,
+        .short_width = 316,
+        .long_width  = 1020,
+        .reset_limit = 1800,
+        .sync_width  = 0,
+        .tolerance   = 80, // us
+        .decode_fn   = &akhan_rke_callback,
+        .fields      = output_fields,
 };
