@@ -11,12 +11,31 @@
 */
 
 /**
-Ambient Weather F007TH Thermo-Hygrometer.
+Decode Ambient Weather F007TH, F012TH, TF 30.3208.02, SwitchDoc F016TH.
 
-Also: TFA senders 30.3208.02 from the TFA "Klima-Monitor" 30.3054,
-also: SwitchDoc Labs F016TH.
+Devices supported:
+
+- Ambient Weather F007TH Thermo-Hygrometer.
+- Ambient Weather F012TH Indoor/Display Thermo-Hygrometer.
+- TFA senders 30.3208.02 from the TFA "Klima-Monitor" 30.3054,
+- SwitchDoc Labs F016TH.
+
+This decoder handles the 433mhz/868mhz thermo-hygrometers.
+The 915mhz (WH*) family of devices use different modulation/encoding.
+
+
+Byte 0   Byte 1   Byte 2   Byte 3   Byte 4   Byte 5
+xxxxMMMM IIIIIIII BCCCTTTT TTTTTTTT HHHHHHHH MMMMMMMM
+
+- x: Unknown 0x04 on F007TH/F012TH
+- M: Model Number?, 0x05 on F007TH/F012TH/SwitchDocLabs F016TH
+- I: ID byte (8 bits), volatie, changes at power up,
+- B: Battery Low
+- C: Channel (3 bits 1-8) - F007TH set by Dip switch, F012TH soft setting
+- T: Temperature 12 bits - Fahrenheit * 10 + 400
+- H: Humidity (8 bits)
+- M: Message integrity check LFSR Digest-8, gen 0x98, key 0x3e, init 0x64
 
-The check is an LFSR Digest-8, gen 0x98, key 0x3e, init 0x64
 */
 
 #include "decoder.h"
@@ -31,25 +50,55 @@ static int ambient_weather_decode(r_device *decoder, bitbuffer_t *bitbuffer, uns
     int humidity;
     data_t *data;
 
-    bitbuffer_extract_bytes(bitbuffer, row, bitpos, b, 6*8);
+    bitbuffer_extract_bytes(bitbuffer, row, bitpos, b, 6 * 8);
 
-    uint8_t expected = b[5];
+    uint8_t expected   = b[5];
     uint8_t calculated = lfsr_digest8(b, 5, 0x98, 0x3e) ^ 0x64;
 
     if (expected != calculated) {
-        if (decoder->verbose) {
-            bitrow_printf(b, 48, "%s: Checksum error, expected: %02x calculated: %02x\n", __func__, expected, calculated);
-        }
+        decoder_logf_bitrow(decoder, 1, __func__, b, 48, "Checksum error, expected: %02x calculated: %02x", expected, calculated);
         return DECODE_FAIL_MIC;
     }
 
     // int model_number = b[0] & 0x0F; // fixed 0x05, at least for "SwitchDoc Labs F016TH"
-    deviceID = b[1];
+    deviceID     = b[1];
     isBatteryLow = (b[2] & 0x80) != 0; // if not zero, battery is low
-    channel = ((b[2] & 0x70) >> 4) + 1;
-    int temp_f = ((b[2] & 0x0f) << 8) | b[3];
-    temperature = (temp_f - 400) * 0.1f;
-    humidity = b[4];
+    channel      = ((b[2] & 0x70) >> 4) + 1;
+    int temp_f   = ((b[2] & 0x0f) << 8) | b[3];
+    temperature  = (temp_f - 400) * 0.1f;
+    humidity     = b[4];
+
+    /*
+    Sanity checks to reduce false positives and other bad data
+
+    Packets with Bad data often pass the MIC check.
+
+    - humidity > 100 (such as 255) and
+    - temperatures > 140 F (such as 369.5 F and 348.8 F
+
+    Specs in the F007TH and F012TH manuals state the range is:
+
+    - Temperature: -40 to 140 F
+    - Humidity: 10 to 99%
+
+    @todo - sanity check b[0] "model number"
+
+    - 0x45 - F007TH and F012TH
+    - 0x?5 - SwitchDocLabs F016TH temperature sensor (based on comment b[0] & 0x0f == 5)
+    - ? - TFA 30.3208.02
+
+    */
+
+    if (humidity < 0 || humidity > 100) {
+        decoder_logf_bitrow(decoder, 1, __func__, b, 48, "Humidity failed sanity check 0x%02x", humidity);
+        return DECODE_FAIL_SANITY;
+    }
+
+    if (temperature < -40.0 || temperature > 140.0) {
+        decoder_logf_bitrow(decoder, 1, __func__, b, 48, "Temperature failed sanity check 0x%03x", temp_f);
+        return DECODE_FAIL_SANITY;
+    }
+
 
     /* clang-format off */
     data = data_make(
@@ -89,14 +138,16 @@ static int ambient_weather_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         while ((bitpos = bitbuffer_search(bitbuffer, row, bitpos, preamble_pattern, 12)) + 8 + 6 * 8 <=
                 bitbuffer->bits_per_row[row]) {
             ret = ambient_weather_decode(decoder, bitbuffer, row, bitpos + 8);
-            if (ret > 0) return ret; // for now, break after first successful message
+            if (ret > 0)
+                return ret; // for now, break after first successful message
             bitpos += 16;
         }
         bitpos = 0;
         while ((bitpos = bitbuffer_search(bitbuffer, row, bitpos, preamble_inverted, 12)) + 8 + 6 * 8 <=
                 bitbuffer->bits_per_row[row]) {
             ret = ambient_weather_decode(decoder, bitbuffer, row, bitpos + 8);
-            if (ret > 0) return ret; // for now, break after first successful message
+            if (ret > 0)
+                return ret; // for now, break after first successful message
             bitpos += 15;
         }
     }
@@ -124,6 +175,5 @@ r_device ambient_weather = {
         .long_width  = 0, // not used
         .reset_limit = 2400,
         .decode_fn   = &ambient_weather_callback,
-        .disabled    = 0,
         .fields      = output_fields,
 };
