@@ -71,25 +71,21 @@ static int auriol_afw2a1_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 
     b = bitbuffer->bb[row];
 
-    id          = b[0];
-    battery_ok  = b[1] >> 7;
-    tx_button   = (b[1] & 0x40) >> 6;
-    channel     = (b[1] & 0x30) >> 4;
-    temp_raw    = (int16_t)(((b[1] & 0x0f) << 12) | (b[2] << 4)); // uses sign extend
-    temp_c      = (temp_raw >> 4) * 0.1f;
+    id         = b[0];
+    battery_ok = b[1] >> 7;
+    tx_button  = (b[1] & 0x40) >> 6;
+    channel    = (b[1] & 0x30) >> 4;
+    temp_raw   = (int16_t)(((b[1] & 0x0f) << 12) | (b[2] << 4)); // uses sign extend
+    temp_c     = (temp_raw >> 4) * 0.1f;
     // 0xa is fixed. If it differs, it is a wrong device. Could anyone confirm that?
     if ((b[3] >> 4) != 0xa) {
-        if (decoder->verbose) {
-            fprintf(stderr, "Not an Auriol-AFW2A1 device\n");
-        }
+        decoder_log(decoder, 1, __func__, "Not an Auriol-AFW2A1 device");
         return DECODE_FAIL_SANITY;
     }
     humidity = (((b[3] & 0x0f) << 4) | (b[4] >> 4));
 
     if ((humidity > 0x64) || (humidity < 0x00) || (temp_c < -51.1) || (temp_c > 76.7)) {
-        if (decoder->verbose) {
-            fprintf(stderr, "Auriol-AFW2A1 data error\n");
-        }
+        decoder_log(decoder, 1, __func__, "Auriol-AFW2A1 data error");
         return DECODE_FAIL_SANITY;
     }
 
@@ -130,6 +126,5 @@ r_device auriol_afw2a1 = {
         .gap_limit   = 2012,
         .reset_limit = 3954,
         .decode_fn   = &auriol_afw2a1_decode,
-        .disabled    = 0, // No side effects known.
         .fields      = output_fields,
 };
