@@ -42,12 +42,14 @@ static int blyss_callback(r_device *decoder, bitbuffer_t *bitbuffer)
 
         sprintf(id_str, "%02x%02x%02x%02x", b[0], b[1], b[2], b[3]);
 
+        /* clang-format off */
         data = data_make(
                 "model",    "", DATA_STRING, "Blyss-DC5ukwh",
                 "id",       "", DATA_STRING, id_str,
                 NULL);
-        decoder_output_data(decoder, data);
+        /* clang-format on */
 
+        decoder_output_data(decoder, data);
         return 1;
     }
 
@@ -55,19 +57,18 @@ static int blyss_callback(r_device *decoder, bitbuffer_t *bitbuffer)
 }
 
 static char *output_fields[] = {
-    "model",
-    "id",
-    NULL
+        "model",
+        "id",
+        NULL,
 };
 
 r_device blyss = {
-    .name           = "Blyss DC5-UK-WH",
-    .modulation     = OOK_PULSE_PWM,
-    .short_width    = 500,
-    .long_width     = 1500,
-    .gap_limit      = 2500,
-    .reset_limit    = 8000,
-    .decode_fn      = &blyss_callback,
-    .disabled       = 0,
-    .fields         = output_fields,
+        .name        = "Blyss DC5-UK-WH",
+        .modulation  = OOK_PULSE_PWM,
+        .short_width = 500,
+        .long_width  = 1500,
+        .gap_limit   = 2500,
+        .reset_limit = 8000,
+        .decode_fn   = &blyss_callback,
+        .fields      = output_fields,
 };
