@@ -71,9 +71,7 @@ static int bresser_5in1_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     if (bitbuffer->num_rows != 1
             || bitbuffer->bits_per_row[0] < 248
             || bitbuffer->bits_per_row[0] > 440) {
-        if (decoder->verbose > 1) {
-            fprintf(stderr, "%s: bit_per_row %u out of range\n", __func__, bitbuffer->bits_per_row[0]);
-        }
+        decoder_logf(decoder, 2, __func__, "bit_per_row %u out of range", bitbuffer->bits_per_row[0]);
         return DECODE_ABORT_EARLY; // Unrecognized data
     }
 
@@ -86,9 +84,7 @@ static int bresser_5in1_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     start_pos += sizeof (preamble_pattern) * 8;
     len = bitbuffer->bits_per_row[0] - start_pos;
     if (((len + 7) / 8) < sizeof (msg)) {
-        if (decoder->verbose > 1) {
-            fprintf(stderr, "%s: %u too short\n", __func__, len);
-        }
+        decoder_logf(decoder, 2, __func__, "%u too short", len);
         return DECODE_ABORT_LENGTH; // message too short
     }
     // truncate any excessive bits
@@ -99,9 +95,7 @@ static int bresser_5in1_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     // First 13 bytes need to match inverse of last 13 bytes
     for (unsigned col = 0; col < sizeof (msg) / 2; ++col) {
         if ((msg[col] ^ msg[col + 13]) != 0xff) {
-            if (decoder->verbose > 1) {
-                fprintf(stderr, "%s: Parity wrong at %u\n", __func__, col);
-            }
+            decoder_logf(decoder, 2, __func__, "Parity wrong at %u", col);
             return DECODE_FAIL_MIC; // message isn't correct
         }
     }
@@ -187,6 +181,5 @@ r_device bresser_5in1 = {
         .long_width  = 124,
         .reset_limit = 25000,
         .decode_fn   = &bresser_5in1_decode,
-        .disabled    = 0,
         .fields      = output_fields,
 };
