@@ -25,6 +25,11 @@ bytes:
 - Byte 8: Checksum
 
 Power calculations come from Nathaniel Elijah's program EfergyRPI_001.
+
+Test codes:
+- Current   4.64 A: {65}0cc055604a41030f8
+- Current 185.16 A: {65}0cc055605c9408798
+
 */
 
 #include "decoder.h"
@@ -55,7 +60,6 @@ static int efergy_e2_classic_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         }
     }
 
-
     // Sometimes pulses and gaps are mixed up. If this happens, invert
     // all bytes to get correct interpretation.
     if (bytes[0] & 0xf0) {
@@ -65,13 +69,12 @@ static int efergy_e2_classic_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     }
 
     int zero_count = 0;
-    for (int i=0; i<8; i++) {
+    for (int i = 0; i < 8; i++) {
         if (bytes[i] == 0)
             zero_count++;
     }
     if (zero_count++ > 5)
-        return DECODE_FAIL_SANITY;  // too many Null bytes
-
+        return DECODE_FAIL_SANITY; // too many Null bytes
 
     unsigned checksum = add_bytes(bytes, 7);
 
@@ -87,7 +90,7 @@ static int efergy_e2_classic_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     uint8_t interval = (((bytes[3] & 0x30) >> 4) + 1) * 6;
     uint8_t battery  = (bytes[3] & 0x40) >> 6;
     uint8_t fact     = -(int8_t)bytes[6] + 15;
-    if (fact < 9 || fact > 20) // full range unknown so far
+    if (fact < 7 || fact > 20) // full range unknown so far
         return DECODE_FAIL_SANITY; // invalid exponent
     float current_adc = (float)(bytes[4] << 8 | bytes[5]) / (1 << fact);
 
@@ -127,6 +130,5 @@ r_device efergy_e2_classic = {
         .gap_limit   = 200,
         .reset_limit = 400,
         .decode_fn   = &efergy_e2_classic_callback,
-        .disabled    = 0,
         .fields      = output_fields,
 };
