@@ -85,8 +85,7 @@ static int efergy_optical_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     crc = crc16(bytes, 10, 0x1021, 0x0000);
 
     if (crc != csum1) {
-        if (decoder->verbose)
-            fprintf(stderr, "%s: CRC error.\n", __func__);
+        decoder_log(decoder, 1, __func__, "CRC error.");
         return DECODE_FAIL_MIC;
     }
 
@@ -99,16 +98,16 @@ static int efergy_optical_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     // - red led (every 30s):    bytes[3]=64 (0100 0000)
     // - orange led (every 60s): bytes[3]=80 (0101 0000)
     // - green led (every 90s):  bytes[3]=96 (0110 0000)
-    seconds = (((bytes[3] & 0x30 ) >> 4 ) + 1) * 30.0;
+    seconds = (((bytes[3] & 0x30) >> 4) + 1) * 30.0;
 
     pulsecount = bytes[8];
 
-    energy = (((float)pulsecount/n_imp) * (3600/seconds));
+    energy = (((float)pulsecount / n_imp) * (3600 / seconds));
 
-    //New code for calculating various energy values for differing pulse-kwh values
+    // New code for calculating various energy values for differing pulse-kwh values
     const int imp_kwh[] = {4000, 3200, 2000, 1000, 500, 0};
     for (unsigned i = 0; imp_kwh[i] != 0; ++i) {
-        energy = (((float)pulsecount/imp_kwh[i]) * (3600/seconds));
+        energy = (((float)pulsecount / imp_kwh[i]) * (3600 / seconds));
 
         /* clang-format off */
         data = data_make(
@@ -143,6 +142,5 @@ r_device efergy_optical = {
         .sync_width  = 500,
         .reset_limit = 400,
         .decode_fn   = &efergy_optical_callback,
-        .disabled    = 0,
         .fields      = output_fields,
 };
