@@ -120,8 +120,8 @@ static int ert_idm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     uint16_t PacketCRC;
     // char  PacketCRC_str[8];
 
-    if (decoder->verbose && bitbuffer->bits_per_row[0] > 600) {
-        fprintf(stderr, "%s: rows=%hu, row0 len=%hu\n", __func__, bitbuffer->num_rows, bitbuffer->bits_per_row[0]);
+    if (bitbuffer->bits_per_row[0] > 600) {
+        decoder_logf(decoder, 1, __func__, "rows=%hu, row0 len=%hu", bitbuffer->num_rows, bitbuffer->bits_per_row[0]);
     }
 
     if (bitbuffer->bits_per_row[0] < IDM_PACKET_BITLEN) {
@@ -130,9 +130,7 @@ static int ert_idm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 
     sync_index = bitbuffer_search(bitbuffer, 0, 0, idm_frame_sync, 24);
 
-    if (decoder->verbose) {
-        fprintf(stderr, "%s: sync_index=%u\n", __func__, sync_index);
-    }
+    decoder_logf(decoder, 1, __func__, "sync_index=%u", sync_index);
 
     if (sync_index >= bitbuffer->bits_per_row[0]) {
         return DECODE_ABORT_EARLY;
@@ -144,9 +142,7 @@ static int ert_idm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 
     // bitbuffer_debug(bitbuffer);
     bitbuffer_extract_bytes(bitbuffer, 0, sync_index, b, IDM_PACKET_BITLEN);
-    if (decoder->verbose) {
-        bitrow_printf(b, IDM_PACKET_BITLEN, "%s bitrow_printf", __func__);
-    }
+    decoder_log_bitrow(decoder, 1, __func__, b, IDM_PACKET_BITLEN, "");
 
     // uint32_t t_16; // temp vars
     // uint32_t t_32;
@@ -205,8 +201,7 @@ static int ert_idm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     for (int j = 0; j < 6; j++) {
         p += sprintf(p, "%02X", b[13 + j]);
     }
-    if (decoder->verbose > 1)
-        bitrow_printf(&b[13], 6 * 8, "%s TamperCounters_str   %s\t", __func__, TamperCounters_str);
+    decoder_logf_bitrow(decoder, 2, __func__, &b[13], 6 * 8, "TamperCounters_str   %s", TamperCounters_str);
 
     AsynchronousCounters = (b[19] << 8 | b[20]);
     // snprintf(AsynchronousCounters_str, sizeof(AsynchronousCounters_str), "0x%04X", AsynchronousCounters);
@@ -217,16 +212,13 @@ static int ert_idm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     for (int j = 0; j < 6; j++) {
         p += sprintf(p, "%02X", b[21 + j]);
     }
-    if (decoder->verbose > 1)
-        bitrow_printf(&b[21], 6 * 8, "%s PowerOutageFlags_str %s\t", __func__, PowerOutageFlags_str);
+    decoder_logf_bitrow(decoder, 2, __func__, &b[21], 6 * 8, "PowerOutageFlags_str %s", PowerOutageFlags_str);
 
     LastConsumptionCount = ((uint32_t)b[27] << 24) | (b[28] << 16) | (b[29] << 8) | (b[30]);
-    if (decoder->verbose)
-        bitrow_printf(&b[27], 32, "%s LastConsumptionCount %d\t", __func__, LastConsumptionCount);
+    decoder_logf_bitrow(decoder, 1, __func__, &b[27], 32, "LastConsumptionCount %d", LastConsumptionCount);
 
     // DifferentialConsumptionIntervals : 47 intervals of 9-bit unsigned integers
-    if (decoder->verbose > 1)
-        bitrow_printf(&b[31], 423, "%s DifferentialConsumptionIntervals", __func__);
+    decoder_log_bitrow(decoder, 2, __func__, &b[31], 423, "DifferentialConsumptionIntervals");
     unsigned pos = sync_index + (31 * 8);
     for (int j = 0; j < 47; j++) {
         uint8_t buffy[4] = {0};
@@ -236,11 +228,10 @@ static int ert_idm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
         pos += 9;
     }
     if (decoder->verbose > 1) {
-        fprintf(stderr, "%s DifferentialConsumptionIntervals:\n\t", __func__);
+        decoder_log(decoder, 2, __func__, "DifferentialConsumptionIntervals");
         for (int j = 0; j < 47; j++) {
-            fprintf(stderr, "%d ", DifferentialConsumptionIntervals[j]);
+            decoder_logf(decoder, 2, __func__, "%d", DifferentialConsumptionIntervals[j]);
         }
-        fprintf(stderr, "\n");
     }
 
     TransmitTimeOffset = (b[84] << 8 | b[85]);
@@ -254,7 +245,7 @@ static int ert_idm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     // id info from https://github.com/bemasher/rtlamr/wiki/Compatible-Meters
 
     char *meter_type = get_meter_type_name(ERTType);
-    // fprintf(stderr, "meter_type = %s\n", meter_type);
+    // decoder_logf(decoder, 0, __func__, "meter_type = %s", meter_type);
 
     /*
         Field key names and format set to  match rtlamr field names
@@ -380,8 +371,8 @@ static int ert_netidm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     uint16_t PacketCRC;
     // char  PacketCRC_str[8];
 
-    if (decoder->verbose && bitbuffer->bits_per_row[0] > 600) {
-        fprintf(stderr, "%s: rows=%d, row0 len=%hu\n", __func__, bitbuffer->num_rows, bitbuffer->bits_per_row[0]);
+    if (bitbuffer->bits_per_row[0] > 600) {
+        decoder_logf(decoder, 1, __func__, "rows=%d, row0 len=%hu", bitbuffer->num_rows, bitbuffer->bits_per_row[0]);
     }
 
     if (bitbuffer->bits_per_row[0] < IDM_PACKET_BITLEN) {
@@ -390,9 +381,7 @@ static int ert_netidm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 
     sync_index = bitbuffer_search(bitbuffer, 0, 0, idm_frame_sync, 24);
 
-    if (decoder->verbose) {
-        fprintf(stderr, "%s: sync_index=%u\n", __func__, sync_index);
-    }
+    decoder_logf(decoder, 1, __func__, "sync_index=%u", sync_index);
 
     if (sync_index >= bitbuffer->bits_per_row[0]) {
         return DECODE_ABORT_EARLY;
@@ -403,8 +392,7 @@ static int ert_netidm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     }
 
     bitbuffer_extract_bytes(bitbuffer, 0, sync_index, b, IDM_PACKET_BITLEN);
-    if (decoder->verbose)
-        bitrow_printf(b, IDM_PACKET_BITLEN, "%s bitrow_printf", __func__);
+    decoder_log_bitrow(decoder, 1, __func__, b, IDM_PACKET_BITLEN, "");
 
     // uint32_t t_16; // temp vars
     // uint32_t t_32;
@@ -463,9 +451,7 @@ static int ert_netidm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     for (int j = 0; j < 6; j++) {
         p += sprintf(p, "%02X", b[13 + j]);
     }
-    if (decoder->verbose > 1)
-        bitrow_printf(&b[13], 6 * 8, "%s TamperCounters_str   %s\t", __func__, TamperCounters_str);
-
+    decoder_logf_bitrow(decoder, 2, __func__, &b[13], 6 * 8, "TamperCounters_str   %s", TamperCounters_str);
 
     //  should this be included ?
     p = Unknown_field_1_str;
@@ -474,10 +460,7 @@ static int ert_netidm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     for (int j = 0; j < 7; j++) {
         p += sprintf(p, "%02X", b[19 + j]);
     }
-    if (decoder->verbose) {
-        bitrow_printf(&b[19], 7 * 8, "%s Unknown_field_1 %s\t", __func__, Unknown_field_1_str);
-        bitrow_debug(&b[19], 7 * 8);
-    }
+    decoder_logf_bitrow(decoder, 1, __func__, &b[19], 7 * 8, "Unknown_field_1 %s", Unknown_field_1_str);
 
     // 3 bytes
     LastGenerationCount = ((uint32_t)(b[26] << 16)) | (b[27] << 8) | (b[28]);
@@ -489,33 +472,28 @@ static int ert_netidm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     for (int j = 0; j < 3; j++) {
         p += sprintf(p, "%02X", b[29 + j]);
     }
-    if (decoder->verbose)
-        bitrow_printf(&b[29], 3 * 8, "%s Unknown_field_1 %s\t", __func__, Unknown_field_2_str);
+    decoder_logf_bitrow(decoder, 1, __func__, &b[29], 3 * 8, "Unknown_field_1 %s", Unknown_field_2_str);
 
     LastConsumptionCount = ((uint32_t)b[32] << 24) | (b[33] << 16) | (b[34] << 8) | (b[35]);
 
-    if (decoder->verbose)
-        bitrow_printf(&b[32], 32, "%s LastConsumptionCount %d\t", __func__, LastConsumptionCount);
+    decoder_logf_bitrow(decoder, 1, __func__, &b[32], 32, "LastConsumptionCount %d", LastConsumptionCount);
 
     // DifferentialConsumptionIntervals[] = 27 intervals of 14-bit unsigned integers.
     unsigned pos = sync_index + (36 * 8);
-    if (decoder->verbose)
-        bitrow_printf(&b[36], 48 * 8, "%s DifferentialConsumptionIntervals", __func__);
+    decoder_log_bitrow(decoder, 1, __func__, &b[36], 48 * 8, "DifferentialConsumptionIntervals");
     for (int j = 0; j < 27; j++) {
         uint8_t buffy[4] = {0};
 
         bitbuffer_extract_bytes(bitbuffer, 0, pos, buffy, 14);
         DifferentialConsumptionIntervals[j] = ((uint16_t)buffy[0] << 6) | (buffy[1] >> 2);
-        // bitrow_printf(buffy, 14, "%d\t%d\t", j, DifferentialConsumptionIntervals[j]);
+        // decoder_logf_bitrow(decoder, 0, __func__, buffy, 14, "%d %d", j, DifferentialConsumptionIntervals[j]);
         pos += 14;
     }
     if (decoder->verbose) {
-        fprintf(stderr, "%s DifferentialConsumptionIntervals:\n\t", __func__);
+        decoder_log(decoder, 1, __func__, "DifferentialConsumptionIntervals");
         for (int j = 0; j < 27; j++) {
-            fprintf(stderr, "%d ", DifferentialConsumptionIntervals[j]);
+            decoder_logf(decoder, 1, __func__, "%d", DifferentialConsumptionIntervals[j]);
         }
-        fprintf(stderr, "\n");
-        // bitrow_debug(&b[36], 48*8);
     }
 
     TransmitTimeOffset = (b[84] << 8 | b[85]);
@@ -549,9 +527,9 @@ static int ert_netidm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     }
     */
 
-    char *meter_type =  get_meter_type_name(ERTType);
+    char *meter_type = get_meter_type_name(ERTType);
 
-    // fprintf(stderr, "meter_type = %s\n", meter_type);
+    // decoder_logf(decoder, 0, __func__, "meter_type = %s", meter_type);
 
     /*
         Field key names and format set to  match rtlamr field names
@@ -650,7 +628,6 @@ r_device ert_idm = {
         // .gap_limit   = 2500,
         // .reset_limit = 4000,
         .decode_fn = &ert_idm_decode,
-        .disabled  = 0,
         .fields    = output_fields,
 };
 
@@ -664,6 +641,5 @@ r_device ert_netidm = {
         // .gap_limit   = 2500,
         // .reset_limit = 4000,
         .decode_fn = &ert_netidm_decode,
-        .disabled  = 0,
         .fields    = output_fields,
 };
