@@ -92,8 +92,12 @@ struct flex_params {
     uint8_t match_bits[128];
     unsigned preamble_len;
     uint8_t preamble_bits[128];
+    uint32_t symbol_zero;
+    uint32_t symbol_one;
+    uint32_t symbol_sync;
     struct flex_get getter[GETTER_SLOTS];
     unsigned decode_uart;
+    char const *fields[7 + GETTER_SLOTS + 1]; // NOTE: needs to match output_fields
 };
 
 static void print_row_bytes(char *row_bytes, uint8_t *bits, int num_bits)
@@ -133,13 +137,16 @@ static void render_getters(data_t *data, uint8_t *bits, struct flex_params *para
                     NULL);
             } else {
                 data_append(data,
-                    getter->name, "", DATA_INT, val,
-                    NULL);
+                        getter->name, "", DATA_INT, val,
+                        NULL);
             }
         }
     }
 }
 
+/**
+Generic flex decoder.
+*/
 static int flex_callback(r_device *decoder, bitbuffer_t *bitbuffer)
 {
     int i;
@@ -220,13 +227,29 @@ static int flex_callback(r_device *decoder, bitbuffer_t *bitbuffer)
             return DECODE_FAIL_SANITY;
     }
 
+    if (params->symbol_zero) {
+        uint32_t zero = params->symbol_zero;
+        uint32_t one  = params->symbol_one;
+        uint32_t sync = params->symbol_sync;
+
+        for (i = 0; i < bitbuffer->num_rows; i++) {
+            // TODO: refactor to bitbuffer_decode_symbol_row()
+            unsigned len    = bitbuffer->bits_per_row[i];
+            bitbuffer_t tmp = {0};
+            len             = extract_bits_symbols(bitbuffer->bb[i], 0, len, zero, one, sync, tmp.bb[0]);
+            memcpy(bitbuffer->bb[i], tmp.bb[0], len); // safe to write over: can only be shorter
+            bitbuffer->bits_per_row[i] = len;
+        }
+        // TODO: apply min_bits, max_bits check
+    }
+
     if (params->decode_uart) {
         for (i = 0; i < bitbuffer->num_rows; i++) {
             // TODO: refactor to bitbuffer_decode_uart_row()
             unsigned len = bitbuffer->bits_per_row[i];
             bitbuffer_t tmp = {0};
             len = extract_bytes_uart(bitbuffer->bb[i], 0, len, tmp.bb[0]);
-            memcpy(bitbuffer->bb[i], tmp.bb[0], len);
+            memcpy(bitbuffer->bb[i], tmp.bb[0], len); // safe to write over: can only be shorter
             bitbuffer->bits_per_row[i] = len * 8;
         }
     }
@@ -242,7 +265,7 @@ static int flex_callback(r_device *decoder, bitbuffer_t *bitbuffer)
 
         /* clang-format off */
         data = data_make(
-                "model", "", DATA_STRING, params->name, // "User-defined model"
+                "model", "", DATA_STRING, params->name, // "User-defined"
                 "count", "", DATA_INT, match_count,
                 "num_rows", "", DATA_INT, bitbuffer->num_rows,
                 "len", "", DATA_INT, bitbuffer->bits_per_row[r],
@@ -260,7 +283,7 @@ static int flex_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     if (params->count_only) {
         /* clang-format off */
         data = data_make(
-                "model", "", DATA_STRING, params->name, // "User-defined model"
+                "model", "", DATA_STRING, params->name, // "User-defined"
                 "count", "", DATA_INT, match_count,
                 NULL);
         /* clang-format on */
@@ -291,7 +314,7 @@ static int flex_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     }
     /* clang-format off */
     data = data_make(
-            "model", "", DATA_STRING, params->name, // "User-defined model"
+            "model", "", DATA_STRING, params->name, // "User-defined"
             "count", "", DATA_INT, match_count,
             "num_rows", "", DATA_INT, bitbuffer->num_rows,
             "rows", "", DATA_ARRAY, data_array(bitbuffer->num_rows, DATA_DATA, row_data),
@@ -313,17 +336,19 @@ static char *output_fields[] = {
         "num_rows",
         "rows",
         "codes",
+        // "len", // unique only
+        // "data", // unique only
         NULL,
 };
 
-static void usage()
+static void usage(void)
 {
     fprintf(stderr,
             "Use -X <spec> to add a general purpose decoder. For usage use -X help\n");
     exit(1);
 }
 
-static void help()
+static void help(void)
 {
     fprintf(stderr,
             "\t\t= Flex decoder spec =\n"
@@ -343,7 +368,8 @@ static void help()
             "<name> can be any descriptive name tag you need in the output\n"
             "<modulation> is one of:\n"
             "\tOOK_MC_ZEROBIT :  Manchester Code with fixed leading zero bit\n"
-            "\tOOK_PCM :         Pulse Code Modulation (RZ or NRZ)\n"
+            "\tOOK_PCM :         Non Return to Zero coding (Pulse Code)\n"
+            "\tOOK_RZ :          Return to Zero coding (Pulse Code)\n"
             "\tOOK_PPM :         Pulse Position Modulation\n"
             "\tOOK_PWM :         Pulse Width Modulation\n"
             "\tOOK_DMC :         Differential Manchester Code\n"
@@ -355,7 +381,7 @@ static void help()
             "\tFSK_MC_ZEROBIT :  Manchester Code with fixed leading zero bit\n"
             "<short>, <long>, <sync> are nominal modulation timings in us,\n"
             "<reset>, <gap>, <tolerance> are maximum modulation timings in us:\n"
-            "PCM     short: Nominal width of pulse [us]\n"
+            "PCM/RZ  short: Nominal width of pulse [us]\n"
             "         long: Nominal width of bit period [us]\n"
             "PPM     short: Nominal width of '0' gap [us]\n"
             "         long: Nominal width of '1' gap [us]\n"
@@ -372,6 +398,7 @@ static void help()
             "\t\tuse opt>=n to match at least <n> and opt<=n to match at most <n>\n"
             "\tinvert : invert all bits\n"
             "\treflect : reflect each byte (MSB first to MSB last)\n"
+            "\tdecode_uart : UART 8n1 (10-to-8) decode\n"
             "\tmatch=<bits> : only match if the <bits> are found\n"
             "\tpreamble=<bits> : match and align at the <bits> preamble\n"
             "\t\t<bits> is a row spec of {<bit count>}<bits as hex number>\n"
@@ -386,7 +413,9 @@ static unsigned parse_modulation(char const *str)
     if (!strcasecmp(str, "OOK_MC_ZEROBIT"))
         return OOK_PULSE_MANCHESTER_ZEROBIT;
     else if (!strcasecmp(str, "OOK_PCM"))
-        return OOK_PULSE_PCM_RZ;
+        return OOK_PULSE_PCM;
+    else if (!strcasecmp(str, "OOK_RZ"))
+        return OOK_PULSE_RZ;
     else if (!strcasecmp(str, "OOK_PPM"))
         return OOK_PULSE_PPM;
     else if (!strcasecmp(str, "OOK_PWM"))
@@ -423,13 +452,31 @@ static unsigned parse_bits(const char *code, uint8_t *bitrow)
     }
     unsigned len = bits.bits_per_row[0];
     if (len > 1024) {
-        fprintf(stderr, "Bad flex spec, \"match\", \"preamble\", and getter mask mayb have up to 1024 bits (%d found)!\n", len);
+        fprintf(stderr, "Bad flex spec, \"match\", \"preamble\", and getter mask may have up to 1024 bits (%u found)!\n", len);
         usage();
     }
     memcpy(bitrow, bits.bb[0], (len + 7) / 8);
     return len;
 }
 
+// used for symbol decode, limited to 27 bits (32 - 5).
+static uint32_t parse_symbol(const char *code)
+{
+    bitbuffer_t bits = {0};
+    bitbuffer_parse(&bits, code);
+    if (bits.num_rows != 1) {
+        fprintf(stderr, "Bad flex spec, \"symbol\" needs exactly one bit row (%d found)!\n", bits.num_rows);
+        usage();
+    }
+    unsigned len = bits.bits_per_row[0];
+    if (len > 27) {
+        fprintf(stderr, "Bad flex spec, \"symbol\" may have up to 27 bits (%u found)!\n", len);
+        usage();
+    }
+    uint8_t *b = bits.bb[0];
+    return ((uint32_t)b[0] << 24) | (b[1] << 16) | (b[2] << 8) | (b[3] << 0) | len;
+}
+
 static const char *parse_map(const char *arg, struct flex_get *getter)
 {
     const char *c = arg;
@@ -618,6 +665,13 @@ r_device *flex_create_device(char *spec)
         else if (!strcasecmp(key, "decode_uart"))
             params->decode_uart = val ? atoi(val) : 1;
 
+        else if (!strcasecmp(key, "symbol_zero"))
+            params->symbol_zero = parse_symbol(val);
+        else if (!strcasecmp(key, "symbol_one"))
+            params->symbol_one = parse_symbol(val);
+        else if (!strcasecmp(key, "symbol_sync"))
+            params->symbol_sync = parse_symbol(val);
+
         else if (!strcasecmp(key, "get")) {
             if (get_count < GETTER_SLOTS)
                 parse_getter(val, &params->getter[get_count++]);
@@ -638,6 +692,20 @@ r_device *flex_create_device(char *spec)
     if (params->min_bits > 0 && params->min_repeats < 1)
         params->min_repeats = 1;
 
+    // add getter fields if unique requested
+    if (params->unique) {
+        int i = 0;
+        for (int f = 0; output_fields[f]; ++f) {
+            params->fields[i++] = output_fields[f];
+        }
+        params->fields[i++] = "len";
+        params->fields[i++] = "data";
+        for (int g = 0; g < GETTER_SLOTS && params->getter[g].name; ++g) {
+            params->fields[i++] = params->getter[g].name;
+        }
+        dev->fields = (char **)params->fields;
+    }
+
     // sanity checks
 
     if (!params->name || !*params->name) {
@@ -677,6 +745,15 @@ r_device *flex_create_device(char *spec)
         }
     }
 
+    if (params->symbol_zero && !params->symbol_one) {
+        fprintf(stderr, "Bad flex spec, symbol-one missing!\n");
+        usage();
+    }
+    if (params->symbol_one && !params->symbol_zero) {
+        fprintf(stderr, "Bad flex spec, symbol-zero missing!\n");
+        usage();
+    }
+
     /*
     if (decoder->verbose) {
         fprintf(stderr, "Adding flex decoder \"%s\"\n", params->name);
