@@ -43,7 +43,7 @@ static int generic_motion_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         if ((bitbuffer->bits_per_row[i] != 20)
                 || ((b[1] == 0) && (b[2] == 0))
                 || ((b[1] == 0xff) && (b[2] == 0xff))
-                || count_repeats(bitbuffer, i) < 3)
+                || bitbuffer_count_repeats(bitbuffer, i, 0) < 3)
             continue; // DECODE_ABORT_EARLY
 
         code = (b[0] << 12) | (b[1] << 4) | (b[2] >> 4);
@@ -77,6 +77,5 @@ r_device generic_motion = {
         .gap_limit   = 1200,
         .reset_limit = 2724 * 1.5,
         .decode_fn   = &generic_motion_callback,
-        .disabled    = 0,
         .fields      = output_fields,
 };
