@@ -83,7 +83,7 @@ Between -17C and 0C, 'n' is 60.  Below -17C, 'n' is 360.
 
 static int lacrosse_breezepro_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 {
-    uint8_t const preamble_pattern[] = { 0xd2, 0xaa, 0x2d, 0xd4 };
+    uint8_t const preamble_pattern[] = {0xd2, 0xaa, 0x2d, 0xd4};
 
     data_t *data;
     uint8_t b[11];
@@ -93,9 +93,7 @@ static int lacrosse_breezepro_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     float temp_c, speed_kmh;
 
     if (bitbuffer->bits_per_row[0] < 264) {
-        if (decoder->verbose) {
-            fprintf(stderr, "%s: Wrong packet length: %d\n", __func__, bitbuffer->bits_per_row[0]);
-        }
+        decoder_logf(decoder, 1, __func__, "Wrong packet length: %d", bitbuffer->bits_per_row[0]);
         return DECODE_ABORT_LENGTH;
     }
 
@@ -103,9 +101,7 @@ static int lacrosse_breezepro_decode(r_device *decoder, bitbuffer_t *bitbuffer)
             preamble_pattern, sizeof(preamble_pattern) * 8);
 
     if (offset >= bitbuffer->bits_per_row[0]) {
-        if (decoder->verbose) {
-            fprintf(stderr, "%s: Sync word not found\n", __func__);
-        }
+        decoder_log(decoder, 1, __func__, "Sync word not found");
         return DECODE_ABORT_EARLY;
     }
 
@@ -114,15 +110,11 @@ static int lacrosse_breezepro_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 
     chk = crc8(b, 11, 0x31, 0x00);
     if (chk) {
-        if (decoder->verbose) {
-           fprintf(stderr, "%s: CRC failed!\n", __func__);
-        }
+        decoder_log(decoder, 1, __func__, "CRC failed!");
         return DECODE_FAIL_MIC;
     }
 
-    if (decoder->verbose) {
-        bitbuffer_print(bitbuffer);
-    }
+    decoder_log_bitbuffer(decoder, 1, __func__, bitbuffer, "");
 
     id        = (b[0] << 16) | (b[1] << 8) | b[2];
     flags     = (b[3] & 0xf1); // masks off seq bits
