@@ -95,8 +95,7 @@ static int lacrosse_it(r_device *decoder, bitbuffer_t *bitbuffer, int device29or
         // no preamble detected, move to the next row
         if (start_pos >= bitbuffer->bits_per_row[row])
             continue; // DECODE_ABORT_EARLY
-        if (decoder->verbose)
-            fprintf(stderr, "%s: LaCrosse TX29/35 detected, buffer is %d bits length, device is TX%d\n", __func__, bitbuffer->bits_per_row[row], device29or35);
+        decoder_logf(decoder, 1, __func__, "LaCrosse TX29/35 detected, buffer is %d bits length, device is TX%d", bitbuffer->bits_per_row[row], device29or35);
         // remove preamble and keep only five octets
         uint8_t b[5];
         bitbuffer_extract_bytes(bitbuffer, row, start_pos + 20, b, 40);
@@ -105,15 +104,14 @@ static int lacrosse_it(r_device *decoder, bitbuffer_t *bitbuffer, int device29or
         int r_crc = b[4];
         int c_crc = crc8(b, 4, 0x31, 0x00);
         if (r_crc != c_crc) {
-            if (decoder->verbose)
-                fprintf(stderr, "%s: LaCrosse TX29/35 bad CRC: calculated %02x, received %02x\n", __func__, c_crc, r_crc);
+            decoder_logf(decoder, 1, __func__, "LaCrosse TX29/35 bad CRC: calculated %02x, received %02x", c_crc, r_crc);
             // reject row
             continue; // DECODE_FAIL_MIC
         }
 
         // message "envelope" has been validated, start parsing data
         int sensor_id   = ((b[0] & 0x0f) << 2) | (b[1] >> 6);
-        float temp_c    = 10.0 * (b[1] & 0x0f) + 1.0 * ((b[2] >> 4) & 0x0f) + 0.1 * (b[2] & 0x0f) - 40.0;
+        float temp_c    = 10 * (b[1] & 0x0f) + 1 * ((b[2] >> 4) & 0x0f) + 0.1f * (b[2] & 0x0f) - 40.0f;
         int new_batt    = (b[1] >> 5) & 1;
         int battery_low = b[3] >> 7;
         int humidity    = b[3] & 0x7f;
