@@ -76,9 +76,7 @@ static int m_bus_crc_valid(r_device *decoder, const uint8_t *bytes, unsigned crc
     uint16_t crc_calc = ~crc16(bytes, crc_offset, CRC_POLY, 0);
     uint16_t crc_read = (((uint16_t)bytes[crc_offset] << 8) | bytes[crc_offset+1]);
     if (crc_calc != crc_read) {
-        if (decoder->verbose) {
-            fprintf(stderr, "M-Bus: CRC error: Calculated 0x%0X, Read: 0x%0X\n", (unsigned)crc_calc, (unsigned)crc_read);
-        }
+        decoder_logf(decoder, 1, __func__, "M-Bus: CRC error: Calculated 0x%0X, Read: 0x%0X", (unsigned)crc_calc, (unsigned)crc_read);
         return 0;
     }
     return 1;
@@ -176,7 +174,7 @@ typedef struct {
     uint8_t     data[512];
 } m_bus_data_t;
 
-static float humidity_factor[2] = { 0.1, 1 };
+static float humidity_factor[2] = { 0.1f, 1.0f };
 
 
 static char *oms_hum[4][4] = {
@@ -799,10 +797,8 @@ static int m_bus_decode_format_a(r_device *decoder, const m_bus_data_t *in, m_bu
     // Check length of package is sufficient
     unsigned num_data_blocks = (block1->L-9+15)/16;      // Data blocks are 16 bytes long + 2 CRC bytes (not counted in L)
     if ((block1->L < 9) || ((block1->L-9)+num_data_blocks*2 > in->length-BLOCK1A_SIZE)) {   // add CRC bytes for each data block
-        if (decoder->verbose) {
-            fprintf(stderr, "M-Bus: Package (%u) too short for packet Length: %u\n", in->length, block1->L);
-            fprintf(stderr, "M-Bus: %u > %u\n", (block1->L-9)+num_data_blocks*2, in->length-BLOCK1A_SIZE);
-        }
+        decoder_logf(decoder, 1, __func__, "M-Bus: Package (%u) too short for packet Length: %u", in->length, block1->L);
+        decoder_logf(decoder, 1, __func__, "M-Bus: %u > %u", (block1->L-9)+num_data_blocks*2, in->length-BLOCK1A_SIZE);
         return 0;
     }
 
@@ -840,7 +836,7 @@ static int m_bus_decode_format_b(r_device *decoder, const m_bus_data_t *in, m_bu
 
     // Check length of package is sufficient
     if ((block1->L < 12) || (block1->L+1 > (int)in->length)) {   // L includes all bytes except itself
-        if (decoder->verbose) { fprintf(stderr, "M-Bus: Package too short for Length: %u\n", block1->L); }
+        decoder_logf(decoder, 1, __func__, "M-Bus: Package too short for Length: %u", block1->L);
         return 0;
     }
 
@@ -963,9 +959,7 @@ static int m_bus_mode_c_t_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         return DECODE_ABORT_EARLY;
     }
 
-    if (decoder->verbose) { fprintf(stderr, "PREAMBLE_T: found at: %u\n", bit_offset);
-    bitbuffer_print(bitbuffer);
-    }
+    decoder_logf_bitbuffer(decoder, 1, __func__, bitbuffer, "PREAMBLE_T: found at: %u", bit_offset);
     bit_offset += sizeof(PREAMBLE_T)*8;     // skip preamble
 
     uint8_t next_byte = bitrow_get_byte(bitbuffer->bb[0], bit_offset);
@@ -977,7 +971,7 @@ static int m_bus_mode_c_t_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         bit_offset += 8;
         // Format A
         if (next_byte == 0xCD) {
-            if (decoder->verbose) { fprintf(stderr, "M-Bus: Mode C, Format A\n"); }
+            decoder_log(decoder, 1, __func__, "M-Bus: Mode C, Format A");
             // Extract data
             data_in.length = (bitbuffer->bits_per_row[0]-bit_offset)/8;
             bitbuffer_extract_bytes(bitbuffer, 0, bit_offset, data_in.data, data_in.length*8);
@@ -986,7 +980,7 @@ static int m_bus_mode_c_t_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         } // Format A
         // Format B
         else if (next_byte == 0x3D) {
-            if (decoder->verbose) { fprintf(stderr, "M-Bus: Mode C, Format B\n"); }
+            decoder_log(decoder, 1, __func__, "M-Bus: Mode C, Format B");
             // Extract data
             data_in.length = (bitbuffer->bits_per_row[0]-bit_offset)/8;
             bitbuffer_extract_bytes(bitbuffer, 0, bit_offset, data_in.data, data_in.length*8);
@@ -995,10 +989,7 @@ static int m_bus_mode_c_t_callback(r_device *decoder, bitbuffer_t *bitbuffer)
         }   // Format B
         // Unknown Format
         else {
-            if (decoder->verbose) {
-                fprintf(stderr, "M-Bus: Mode C, Unknown format: 0x%X\n", next_byte);
-                bitbuffer_print(bitbuffer);
-            }
+            decoder_logf_bitbuffer(decoder, 1, __func__, bitbuffer, "M-Bus: Mode C, Unknown format: 0x%X", next_byte);
             return 0;
         }
     }   // Mode C
@@ -1006,15 +997,15 @@ static int m_bus_mode_c_t_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     else {
         mode = "T";
         bit_offset -= 8; // Rewind offset to start of telegram
-        if (decoder->verbose) { fprintf(stderr, "M-Bus: Mode T\n"); }
-        if (decoder->verbose) { fprintf(stderr, "Experimental - Not tested\n"); }
+        decoder_log(decoder, 1, __func__, "M-Bus: Mode T");
+        decoder_log(decoder, 1, __func__, "Experimental - Not tested");
         // Extract data
 
         data_in.length = (bitbuffer->bits_per_row[0]-bit_offset)/12;    // Each byte is encoded into 12 bits
 
-        if (decoder->verbose) { fprintf(stderr, "MBus telegram length: %u\n", data_in.length); }
+        decoder_logf(decoder, 1, __func__, "MBus telegram length: %u", data_in.length);
         if (m_bus_decode_3of6_buffer(bitbuffer->bb[0], bit_offset, data_in.data, data_in.length) < 0) {
-            if (decoder->verbose) fprintf(stderr, "M-Bus: Decoding error\n");
+            decoder_log(decoder, 1, __func__, "M-Bus: Decoding error");
             return 0;
         }
         // Decode
@@ -1049,8 +1040,8 @@ static int m_bus_mode_r_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     }
     bit_offset += sizeof(PREAMBLE_RA)*8;     // skip preamble
 
-    if (decoder->verbose) { fprintf(stderr, "M-Bus: Mode R, Format A\n"); }
-    if (decoder->verbose) { fprintf(stderr, "Experimental - Not tested\n"); }
+    decoder_log(decoder, 1, __func__, "M-Bus: Mode R, Format A");
+    decoder_log(decoder, 1, __func__, "Experimental - Not tested");
     // Extract data
     data_in.length = (bitbuffer->bits_per_row[0]-bit_offset)/8;
     bitbuffer_extract_bytes(bitbuffer, 0, bit_offset, data_in.data, data_in.length*8);
@@ -1093,22 +1084,19 @@ static int m_bus_mode_f_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     bit_offset += 8;
     // Format A
     if (next_byte == 0x8D) {
-        if (decoder->verbose) { fprintf(stderr, "M-Bus: Mode F, Format A\n"); }
-        if (decoder->verbose) { fprintf(stderr, "Not implemented\n"); }
+        decoder_log(decoder, 1, __func__, "M-Bus: Mode F, Format A");
+        decoder_log(decoder, 1, __func__, "Not implemented");
         return 1;
     } // Format A
     // Format B
     else if (next_byte == 0x72) {
-        if (decoder->verbose) { fprintf(stderr, "M-Bus: Mode F, Format B\n"); }
-        if (decoder->verbose) { fprintf(stderr, "Not implemented\n"); }
+        decoder_log(decoder, 1, __func__, "M-Bus: Mode F, Format B");
+        decoder_log(decoder, 1, __func__, "Not implemented");
         return 1;
     }   // Format B
     // Unknown Format
     else {
-        if (decoder->verbose) {
-            fprintf(stderr, "M-Bus: Mode F, Unknown format: 0x%X\n", next_byte);
-            bitbuffer_print(bitbuffer);
-        }
+        decoder_logf_bitbuffer(decoder, 1, __func__, bitbuffer, "M-Bus: Mode F, Unknown format: 0x%X", next_byte);
         return 0;
     }
 
@@ -1148,94 +1136,89 @@ static int m_bus_mode_s_callback(r_device *decoder, bitbuffer_t *bitbuffer)
 
 // NOTE: we'd need to add "value_types_tab X unit_names X n" fields
 static char *output_fields[] = {
-    "model",
-    "mode",
-    "id",
-    "version",
-    "type",
-    "type_string",
-    "CI",
-    "AC",
-    "ST",
-    "CW",
-    "sn",
-    "knx_ctrl",
-    "src",
-    "dst",
-    "l_npci",
-    "tpci",
-    "apci",
-    "crc",
-    "M",
-    "C",
-    "data_length",
-    "data",
-    "mic",
-    "temperature_C",
-    "average_temperature_1h_C",
-    "average_temperature_24h_C",
-    "humidity",
-    "average_humidity_1h",
-    "average_humidity_24h",
-    "minimum_temperature_1h_C",
-    "maximum_temperature_1h_C",
-    "minimum_temperature_24h_C",
-    "maximum_temperature_24h_C",
-    "minimum_humidity_1h",
-    "maximum_humidity_1h",
-    "minimum_humidity_24h",
-    "maximum_humidity_24h",
-    "switch",
-    "counter_0",
-    "counter_1",
-    NULL,
+        "model",
+        "mode",
+        "id",
+        "version",
+        "type",
+        "type_string",
+        "CI",
+        "AC",
+        "ST",
+        "CW",
+        "sn",
+        "knx_ctrl",
+        "src",
+        "dst",
+        "l_npci",
+        "tpci",
+        "apci",
+        "crc",
+        "M",
+        "C",
+        "data_length",
+        "data",
+        "mic",
+        "temperature_C",
+        "average_temperature_1h_C",
+        "average_temperature_24h_C",
+        "humidity",
+        "average_humidity_1h",
+        "average_humidity_24h",
+        "minimum_temperature_1h_C",
+        "maximum_temperature_1h_C",
+        "minimum_temperature_24h_C",
+        "maximum_temperature_24h_C",
+        "minimum_humidity_1h",
+        "maximum_humidity_1h",
+        "minimum_humidity_24h",
+        "maximum_humidity_24h",
+        "switch",
+        "counter_0",
+        "counter_1",
+        NULL,
 };
 
 // Mode C1, C2 (Meter TX), T1, T2 (Meter TX),
 // Frequency 868.95 MHz, Bitrate 100 kbps, Modulation NRZ FSK
 r_device m_bus_mode_c_t = {
-    .name           = "Wireless M-Bus, Mode C&T, 100kbps (-f 868950000 -s 1200000)",     // Minimum samplerate = 1.2 MHz (12 samples of 100kb/s)
-    .modulation     = FSK_PULSE_PCM,
-    .short_width    = 10,   // Bit rate: 100 kb/s
-    .long_width     = 10,   // NRZ encoding (bit width = pulse width)
-    .reset_limit    = 500,  //
-    .decode_fn      = &m_bus_mode_c_t_callback,
-    .disabled       = 0,
-    .fields         = output_fields,
+        .name        = "Wireless M-Bus, Mode C&T, 100kbps (-f 868950000 -s 1200000)", // Minimum samplerate = 1.2 MHz (12 samples of 100kb/s)
+        .modulation  = FSK_PULSE_PCM,
+        .short_width = 10,  // Bit rate: 100 kb/s
+        .long_width  = 10,  // NRZ encoding (bit width = pulse width)
+        .reset_limit = 500, //
+        .decode_fn   = &m_bus_mode_c_t_callback,
+        .fields      = output_fields,
 };
 
-
 // Mode S1, S1-m, S2, T2 (Meter RX),    (Meter RX not so interesting)
 // Frequency 868.3 MHz, Bitrate 32.768 kbps, Modulation Manchester FSK
 r_device m_bus_mode_s = {
-    .name           = "Wireless M-Bus, Mode S, 32.768kbps (-f 868300000 -s 1000000)",   // Minimum samplerate = 1 MHz (15 samples of 32kb/s manchester coded)
-    .modulation     = FSK_PULSE_PCM,
-    .short_width    = (1000.0/32.768),   // ~31 us per bit
-    .long_width     = (1000.0/32.768),
-    .reset_limit    = ((1000.0/32.768)*9), // 9 bit periods
-    .decode_fn      = &m_bus_mode_s_callback,
-    .disabled       = 0,
-    .fields         = output_fields,
+        .name        = "Wireless M-Bus, Mode S, 32.768kbps (-f 868300000 -s 1000000)", // Minimum samplerate = 1 MHz (15 samples of 32kb/s manchester coded)
+        .modulation  = FSK_PULSE_PCM,
+        .short_width = (1000.0 / 32.768), // ~31 us per bit
+        .long_width  = (1000.0 / 32.768),
+        .reset_limit = ((1000.0 / 32.768) * 9), // 9 bit periods
+        .decode_fn   = &m_bus_mode_s_callback,
+        .fields      = output_fields,
 };
 
-
 // Mode C2 (Meter RX)
 // Frequency 869.525 MHz, Bitrate 50 kbps, Modulation Manchester
 //      Note: Not so interesting, as it is only Meter RX
 
-
 // Mode R2
 // Frequency 868.33 MHz, Bitrate 4.8 kbps, Modulation Manchester FSK
 //      Preamble {0x55, 0x54, 0x76, 0x96} (Format A) (B not supported)
 // Untested stub!!! (Need samples)
 r_device m_bus_mode_r = {
-    .name           = "Wireless M-Bus, Mode R, 4.8kbps (-f 868330000)",
-    .modulation     = FSK_PULSE_MANCHESTER_ZEROBIT,
-    .short_width    = (1000.0f / 4.8f / 2),   // ~208 us per bit -> clock half period ~104 us
-    .long_width     = 0,    // Unused
-    .reset_limit    = (1000.0f / 4.8f * 1.5f), // 3 clock half periods
-    .decode_fn      = &m_bus_mode_r_callback,
-    .disabled       = 1,    // Disable per default, as it runs on non-standard frequency
+        .name        = "Wireless M-Bus, Mode R, 4.8kbps (-f 868330000)",
+        .modulation  = FSK_PULSE_MANCHESTER_ZEROBIT,
+        .short_width = (1000.0f / 4.8f / 2),    // ~208 us per bit -> clock half period ~104 us
+        .long_width  = 0,                       // Unused
+        .reset_limit = (1000.0f / 4.8f * 1.5f), // 3 clock half periods
+        .decode_fn   = &m_bus_mode_r_callback,
+        .disabled    = 1, // Disable per default, as it runs on non-standard frequency
 };
 
 // Mode N
@@ -1247,18 +1230,17 @@ r_device m_bus_mode_r = {
 // Bitrate 19.2 kbps, Modulation 4 GFSK (9600 BAUD)
 //      Note: Not currently possible with rtl_433
 
-
 // Mode F2
 // Frequency 433.82 MHz, Bitrate 2.4 kbps, Modulation NRZ FSK
 //      Preamble {0x55, 0xF6, 0x8D} (Format A)
 //      Preamble {0x55, 0xF6, 0x72} (Format B)
 // Untested stub!!! (Need samples)
 r_device m_bus_mode_f = {
-    .name           = "Wireless M-Bus, Mode F, 2.4kbps",
-    .modulation     = FSK_PULSE_PCM,
-    .short_width    = 1000.0f / 2.4f,   // ~417 us
-    .long_width     = 1000.0f / 2.4f,   // NRZ encoding (bit width = pulse width)
-    .reset_limit    = 5000,         // ??
-    .decode_fn      = &m_bus_mode_f_callback,
-    .disabled       = 1,    // Disable per default, as it runs on non-standard frequency
+        .name        = "Wireless M-Bus, Mode F, 2.4kbps",
+        .modulation  = FSK_PULSE_PCM,
+        .short_width = 1000.0f / 2.4f, // ~417 us
+        .long_width  = 1000.0f / 2.4f, // NRZ encoding (bit width = pulse width)
+        .reset_limit = 5000,           // ??
+        .decode_fn   = &m_bus_mode_f_callback,
+        .disabled    = 1, // Disable per default, as it runs on non-standard frequency
 };
