@@ -43,9 +43,9 @@ Layout appears to be:
 
 #include "decoder.h"
 
-static int maverick_et73_sensor_callback(r_device *decoder, bitbuffer_t *bitbuffer)
+static int maverick_et73_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 {
-    int temp1_raw, temp2_raw, row;
+  int temp1_raw, temp2_raw, row;
     float temp1_c, temp2_c;
     uint8_t *bytes;
     unsigned int device;
@@ -68,16 +68,14 @@ static int maverick_et73_sensor_callback(r_device *decoder, bitbuffer_t *bitbuff
 
     device = bytes[0];
 
-    if (decoder->verbose) {
-        fprintf(stderr,"maverick_et73_raw_data:");
-        bitrow_print(bytes, 48);
-    }
+    decoder_log_bitrow(decoder, 1, __func__, bytes, 48, "");
 
-    temp1_raw = (bytes[1] << 4) | ((bytes[2] & 0xf0) );
-    temp2_raw = ((bytes[2] & 0x0f) << 8) | bytes[3];
-
-    temp1_c = temp1_raw * 0.1f;
-    temp2_c = temp2_raw * 0.1f;
+    // Repack the nibbles to form a 12-bit field representing the 2's-complement temperatures,
+    //   then right shift by 4 to sign-extend the 12-bit field to a 16-bit integer for float conversion
+    temp1_raw = (int16_t)( bytes[1]<<8 | ( bytes[2] & 0xf0 ) );
+    temp1_c = (temp1_raw>>4) * 0.1f;
+    temp2_raw = (int16_t)( ( (bytes[2] & 0x0f) << 12) | bytes[3]<<4 );
+    temp2_c = (temp2_raw>>4) * 0.1f;
 
     /* clang-format off */
     data = data_make(
@@ -107,7 +105,6 @@ r_device maverick_et73 = {
         .long_width  = 2050,
         .gap_limit   = 2200,
         .reset_limit = 4400, // 4050 us nominal packet gap
-        .decode_fn   = &maverick_et73_sensor_callback,
-        .disabled    = 0,
+        .decode_fn   = &maverick_et73_decode,
         .fields      = output_fields,
 };
