@@ -10,9 +10,13 @@
 
     License: GPL v2+ (or at your choice, any other OSI-approved Open Source license)
 */
-/**
+/** @fn int ss_sensor_callback(r_device *decoder, bitbuffer_t *bitbuffer)
 Protocol of the SimpliSafe Sensors.
 
+@sa ss_sensor_parser()
+@sa ss_pinentry_parser()
+@sa ss_keypad_commands()
+
 The data is sent leveraging a PiWM Encoding where a long is 1, and a short is 0
 
 All bytes are sent with least significant bit FIRST (1000 0111 = 0xE1)
@@ -44,6 +48,9 @@ static void ss_get_id(char *id, uint8_t *b)
     *p = '\0';
 }
 
+/**
+SimpliSafe protocol for sensors.
+*/
 static int ss_sensor_parser(r_device *decoder, bitbuffer_t *bitbuffer, int row)
 {
     data_t *data;
@@ -85,6 +92,9 @@ static int ss_sensor_parser(r_device *decoder, bitbuffer_t *bitbuffer, int row)
     return 1;
 }
 
+/**
+SimpliSafe protocol for pinentry.
+*/
 static int ss_pinentry_parser(r_device *decoder, bitbuffer_t *bitbuffer, int row)
 {
     data_t *data;
@@ -119,6 +129,9 @@ static int ss_pinentry_parser(r_device *decoder, bitbuffer_t *bitbuffer, int row
     return 1;
 }
 
+/**
+SimpliSafe protocol for keypad commands.
+*/
 static int ss_keypad_commands(r_device *decoder, bitbuffer_t *bitbuffer, int row)
 {
     data_t *data;
@@ -155,21 +168,17 @@ static int ss_keypad_commands(r_device *decoder, bitbuffer_t *bitbuffer, int row
     return 1;
 }
 
-/**
-Protocol of the SimpliSafe Sensors.
-@sa ss_sensor_parser() ss_pinentry_parser() ss_keypad_commands()
-*/
 static int ss_sensor_callback(r_device *decoder, bitbuffer_t *bitbuffer)
 {
     // Require two identical rows.
     int row = bitbuffer_find_repeated_row(bitbuffer, 2, 90);
     if (row < 0)
-      return DECODE_ABORT_EARLY;
+        return DECODE_ABORT_EARLY;
 
     // The row must start with 0xcc5f (0x33a0 inverted).
     uint8_t *b = bitbuffer->bb[row];
     if (b[0] != 0xcc || b[1] != 0x5f)
-      return DECODE_ABORT_EARLY;
+        return DECODE_ABORT_EARLY;
 
     bitbuffer_invert(bitbuffer);
 
@@ -180,8 +189,7 @@ static int ss_sensor_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     } else if (b[2] == 0x44) {
         return ss_keypad_commands(decoder, bitbuffer, row);
     } else {
-        if (decoder->verbose)
-            fprintf(stderr, "Unknown Message Type: %02x\n", b[2]);
+        decoder_logf(decoder, 1, __func__, "Unknown Message Type: %02x", b[2]);
         return DECODE_ABORT_EARLY;
     }
 }
