@@ -45,7 +45,7 @@ static int tfa_pool_thermometer_decode(r_device *decoder, bitbuffer_t *bitbuffer
     b = bitbuffer->bb[row];
 
     checksum_rx = ((b[0] & 0xF0) >> 4);
-    checksum = ((b[0] & 0x0F) +
+    checksum    = ((b[0] & 0x0F) +
                 (b[1] >> 4) +
                 (b[1] & 0x0F) +
                 (b[2] >> 4) +
@@ -53,8 +53,7 @@ static int tfa_pool_thermometer_decode(r_device *decoder, bitbuffer_t *bitbuffer
                 (b[3] >> 4) - 1);
 
     if (checksum_rx != (checksum & 0x0F)) {
-        if (decoder->verbose > 1)
-            bitrow_printf(b, bitbuffer->bits_per_row[row], "%s: checksum fail (%02x) ", __func__, checksum);
+        decoder_logf_bitrow(decoder, 2, __func__, b, bitbuffer->bits_per_row[row], "checksum fail (%02x)", checksum);
         return DECODE_FAIL_MIC;
     }
 
@@ -77,7 +76,6 @@ static int tfa_pool_thermometer_decode(r_device *decoder, bitbuffer_t *bitbuffer
 
     decoder_output_data(decoder, data);
     return 1;
-
 }
 
 static char *output_fields[] = {
@@ -98,6 +96,5 @@ r_device tfa_pool_thermometer = {
         .gap_limit   = 7800,
         .reset_limit = 10000,
         .decode_fn   = &tfa_pool_thermometer_decode,
-        .disabled    = 0,
         .fields      = output_fields,
 };
