@@ -69,20 +69,16 @@ static int visonic_powercode_decode(r_device *decoder, bitbuffer_t *bitbuffer)
 
     // No need to decode/extract values for simple test
     if (!msg[0] && !msg[1] && !msg[2] && !msg[3] && !msg[4]) {
-        if (decoder->verbose > 1) {
-            fprintf(stderr, "%s: DECODE_FAIL_SANITY data all 0x00\n", __func__);
-        }
+        decoder_log(decoder, 2, __func__, "DECODE_FAIL_SANITY data all 0x00");
         return DECODE_FAIL_SANITY;
     }
 
     lrc = xor_bytes(msg, 5);
     if (((lrc >> 4) ^ (lrc & 0xf)) != 0)
-       return DECODE_FAIL_MIC;
+        return DECODE_FAIL_MIC;
 
     // debug
-    if (decoder->verbose > 1) {
-        fprintf(stderr, "%s: data byte is %02x\n", __func__, msg[3]);
-    }
+    decoder_logf(decoder, 2, __func__, "data byte is %02x", msg[3]);
 
     // format device id
     sprintf(id, "%02x%02x%02x", msg[0], msg[1], msg[2]);
@@ -132,6 +128,5 @@ r_device visonic_powercode = {
         .gap_limit   = 900,
         .reset_limit = 5000,
         .decode_fn   = &visonic_powercode_decode,
-        .disabled    = 0,
         .fields      = output_fields,
 };
