@@ -70,15 +70,13 @@ static int wt450_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     data_t *data;
 
     if (bitbuffer->bits_per_row[0] != 36) {
-        if (decoder->verbose)
-            fprintf(stderr, "%s: wrong size of bit per row %d\n", __func__,
+        decoder_logf(decoder, 1, __func__, "wrong size of bit per row %d",
                     bitbuffer->bits_per_row[0]);
         return DECODE_ABORT_LENGTH;
     }
 
-    if (b[0]>>4 != 0xC) {
-        if (decoder->verbose)
-            bitbuffer_printf(bitbuffer, "%s: wrong preamble\n", __func__);
+    if (b[0] >> 4 != 0xC) {
+        decoder_log_bitbuffer(decoder, 1, __func__, bitbuffer, "wrong preamble");
         return DECODE_ABORT_EARLY;
     }
 
@@ -88,8 +86,7 @@ static int wt450_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     parity &= 0x3;
 
     if (parity) {
-        if (decoder->verbose)
-            bitbuffer_printf(bitbuffer, "%s: wrong parity (%x)\n", __func__, parity);
+        decoder_logf_bitbuffer(decoder, 1, __func__, bitbuffer, "wrong parity (%x)", parity);
         return DECODE_FAIL_MIC;
     }
 
@@ -99,7 +96,7 @@ static int wt450_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     humidity      = ((b[1] & 0x7) << 4) | (b[2] >> 4);
     temp_whole    = (b[2] << 4) | (b[3] >> 4);
     temp_fraction = (b[3] & 0xF);
-    temp          = (temp_whole - 50) + (temp_fraction / 16.0);
+    temp          = (temp_whole - 50.0f) + (temp_fraction / 16.0f);
     seq           = (b[4] >> 6);
 
     /* clang-format off */
@@ -137,6 +134,5 @@ r_device wt450 = {
         .reset_limit = 18000,
         .tolerance   = 100, // us
         .decode_fn   = &wt450_callback,
-        .disabled    = 0,
         .fields      = output_fields,
 };
