@@ -195,7 +195,7 @@ typedef struct {
     //char *hass;
 } data_output_mqtt_t;
 
-static void print_mqtt_array(data_output_t *output, data_array_t *array, char const *format)
+static void R_API_CALLCONV print_mqtt_array(data_output_t *output, data_array_t *array, char const *format)
 {
     data_output_mqtt_t *mqtt = (data_output_mqtt_t *)output;
 
@@ -325,7 +325,7 @@ static char *expand_topic(char *topic, char const *format, data_t *data, char co
 }
 
 // <prefix>[/type][/model][/subtype][/channel][/id]/battery: "OK"|"LOW"
-static void print_mqtt_data(data_output_t *output, data_t *data, char const *format)
+static void R_API_CALLCONV print_mqtt_data(data_output_t *output, data_t *data, char const *format)
 {
     UNUSED(format);
     data_output_mqtt_t *mqtt = (data_output_mqtt_t *)output;
@@ -395,14 +395,14 @@ static void print_mqtt_data(data_output_t *output, data_t *data, char const *for
     *orig = '\0'; // restore topic
 }
 
-static void print_mqtt_string(data_output_t *output, char const *str, char const *format)
+static void R_API_CALLCONV print_mqtt_string(data_output_t *output, char const *str, char const *format)
 {
     UNUSED(format);
     data_output_mqtt_t *mqtt = (data_output_mqtt_t *)output;
     mqtt_client_publish(mqtt->mqc, mqtt->topic, str);
 }
 
-static void print_mqtt_double(data_output_t *output, double data, char const *format)
+static void R_API_CALLCONV print_mqtt_double(data_output_t *output, double data, char const *format)
 {
     char str[20];
     // use scientific notation for very big/small values
@@ -421,14 +421,14 @@ static void print_mqtt_double(data_output_t *output, double data, char const *fo
     print_mqtt_string(output, str, format);
 }
 
-static void print_mqtt_int(data_output_t *output, int data, char const *format)
+static void R_API_CALLCONV print_mqtt_int(data_output_t *output, int data, char const *format)
 {
     char str[20];
     snprintf(str, 20, "%d", data);
     print_mqtt_string(output, str, format);
 }
 
-static void data_output_mqtt_free(data_output_t *output)
+static void R_API_CALLCONV data_output_mqtt_free(data_output_t *output)
 {
     data_output_mqtt_t *mqtt = (data_output_mqtt_t *)output;
 
