@@ -37,9 +37,10 @@
 #include "pulse_analyzer.h"
 #include "pulse_detect.h"
 #include "pulse_detect_fsk.h"
-#include "pulse_demod.h"
+#include "pulse_slicer.h"
 #include "rfraw.h"
 #include "data.h"
+#include "raw_output.h"
 #include "r_util.h"
 #include "optparse.h"
 #include "abuf.h"
@@ -83,6 +84,44 @@
 #endif
 #endif
 
+// STDERR_FILENO is not defined in at least MSVC
+#ifndef STDERR_FILENO
+#define STDERR_FILENO 2
+#endif
+
+#ifdef _WIN32
+#include <windows.h>
+#define usleep(us) Sleep((us) / 1000)
+#endif
+
+typedef struct timeval delay_timer_t;
+
+static void delay_timer_init(delay_timer_t *delay_timer)
+{
+    // set to current wall clock
+    get_time_now(delay_timer);
+}
+
+static void delay_timer_wait(delay_timer_t *delay_timer, unsigned delay_us)
+{
+    // sync to wall clock
+    struct timeval now_tv;
+    get_time_now(&now_tv);
+
+    time_t elapsed_s  = now_tv.tv_sec - delay_timer->tv_sec;
+    time_t elapsed_us = 1000000 * elapsed_s + now_tv.tv_usec - delay_timer->tv_usec;
+
+    // set next wanted start time
+    delay_timer->tv_usec += delay_us;
+    while (delay_timer->tv_usec > 1000000) {
+        delay_timer->tv_usec -= 1000000;
+        delay_timer->tv_sec += 1;
+    }
+
+    if ((time_t)delay_us > elapsed_us)
+        usleep(delay_us - elapsed_us);
+}
+
 r_device *flex_create_device(char *spec); // maybe put this in some header file?
 
 static void print_version(void)
@@ -109,12 +148,11 @@ static void usage(int exit_code)
             "       e.g. -t \"antenna=A,bandwidth=4.5M,rfnotch_ctrl=false\"\n"
             "  [-f <frequency>] Receive frequency(s) (default: %i Hz)\n"
             "  [-H <seconds>] Hop interval for polling of multiple frequencies (default: %i seconds)\n"
-            "  [-p <ppm_error] Correct rtl-sdr tuner frequency offset error (default: 0)\n"
+            "  [-p <ppm_error>] Correct rtl-sdr tuner frequency offset error (default: 0)\n"
             "  [-s <sample rate>] Set sample rate (default: %i Hz)\n"
             "\t\t= Demodulator options =\n"
             "  [-R <device> | help] Enable only the specified device decoding protocol (can be used multiple times)\n"
             "       Specify a negative number to disable a device decoding protocol (can be used multiple times)\n"
-            "  [-G] Enable blacklisted device decoding protocols, for testing only.\n"
             "  [-X <spec> | help] Add a general purpose decoder (prepend -R 0 to disable all decoders)\n"
             "  [-Y auto | classic | minmax] FSK pulse detector mode.\n"
             "  [-Y level=<dB level>] Manual detection level used to determine pulses (-1.0 to -30.0) (0=auto).\n"
@@ -135,10 +173,10 @@ static void usage(int exit_code)
             "  [-w <filename> | help] Save data stream to output file (a '-' dumps samples to stdout)\n"
             "  [-W <filename> | help] Save data stream to output file, overwrite existing file\n"
             "\t\t= Data output options =\n"
-            "  [-F kv | json | csv | mqtt | influx | syslog | null | help] Produce decoded output in given format.\n"
+            "  [-F kv | json | csv | mqtt | influx | syslog | trigger | null | help] Produce decoded output in given format.\n"
             "       Append output to file with :<filename> (e.g. -F csv:log.csv), defaults to stdout.\n"
             "       Specify host/port for syslog with e.g. -F syslog:127.0.0.1:1514\n"
-            "  [-M time[:<options>] | protocol | level | noise[:secs] | stats | bits | help] Add various meta data to each output.\n"
+            "  [-M time[:<options>] | protocol | level | noise[:<secs>] | stats | bits | help] Add various meta data to each output.\n"
             "  [-K FILE | PATH | <tag> | <key>=<tag>] Add an expanded token or fixed tag to every output line.\n"
             "  [-C native | si | customary] Convert units in decoded output.\n"
             "  [-n <value>] Specify number of samples to take (each sample is an I/Q pair)\n"
@@ -163,7 +201,7 @@ static void help_protocols(r_device *devices, unsigned num_devices, int exit_cod
             if (devices[i].disabled <= 2) // if not hidden
                 fprintf(stderr, "    [%02u]%c %s\n", i + 1, disabledc, devices[i].name);
         }
-        fprintf(stderr, "\n* Disabled by default, use -R n or -G\n");
+        fprintf(stderr, "\n* Disabled by default, use -R n or a conf file to enable\n");
     }
     exit(exit_code);
 }
@@ -211,12 +249,12 @@ static void help_output(void)
 {
     term_help_printf(
             "\t\t= Output format option =\n"
-            "  [-F kv|json|csv|mqtt|influx|syslog|null] Produce decoded output in given format.\n"
+            "  [-F kv|json|csv|mqtt|influx|syslog|trigger|null] Produce decoded output in given format.\n"
             "\tWithout this option the default is KV output. Use \"-F null\" to remove the default.\n"
             "\tAppend output to file with :<filename> (e.g. -F csv:log.csv), defaults to stdout.\n"
             "\tSpecify MQTT server with e.g. -F mqtt://localhost:1883\n"
             "\tAdd MQTT options with e.g. -F \"mqtt://host:1883,opt=arg\"\n"
-            "\tMQTT options are: user=foo, pass=bar, retain[=0|1], qos=N, <format>[=topic]\n"
+            "\tMQTT options are: user=foo, pass=bar, retain[=0|1], <format>[=topic]\n"
             "\tSupported MQTT formats: (default is all)\n"
             "\t  events: posts JSON event data\n"
             "\t  states: posts JSON state data\n"
@@ -244,7 +282,7 @@ static void help_tags(void)
             "\t\t\"-K loc=gpsd,lat,lon\" (report lat and lon in loc object)\n"
             "\t\t\"-K gpsd\" (full json TPV report, in default \"gps\" object)\n"
             "\t\t\"-K foo=gpsd://127.0.0.1:2947\" (with key and address)\n"
-            "\t\t\"-K bar=gpsd,nmea\" (NMEA deault GPGGA report)\n"
+            "\t\t\"-K bar=gpsd,nmea\" (NMEA default GPGGA report)\n"
             "\t\t\"-K rmc=gpsd,nmea,filter='$GPRMC'\" (NMEA GPRMC report)\n"
             "\tAlso <tag> can be a generic tcp address, e.g.\n"
             "\t\t\"-K foo=tcp:localhost:4000\" (read lines as TCP client)\n"
@@ -261,17 +299,18 @@ static void help_meta(void)
             "  [-M time[:<options>]|protocol|level|noise[:<secs>]|stats|bits] Add various metadata to every output line.\n"
             "\tUse \"time\" to add current date and time meta data (preset for live inputs).\n"
             "\tUse \"time:rel\" to add sample position meta data (preset for read-file and stdin).\n"
-            "\tUse \"time:unix\" to show the seconds since unix epoch as time meta data.\n"
+            "\tUse \"time:unix\" to show the seconds since unix epoch as time meta data. This is always UTC.\n"
             "\tUse \"time:iso\" to show the time with ISO-8601 format (YYYY-MM-DD\"T\"hh:mm:ss).\n"
             "\tUse \"time:off\" to remove time meta data.\n"
             "\tUse \"time:usec\" to add microseconds to date time meta data.\n"
             "\tUse \"time:tz\" to output time with timezone offset.\n"
             "\tUse \"time:utc\" to output time in UTC.\n"
             "\t\t(this may also be accomplished by invocation with TZ environment variable set).\n"
-            "\t\t\"usec\" and \"utc\" can be combined with other options, eg. \"time:unix:utc:usec\".\n"
+            "\t\t\"usec\" and \"utc\" can be combined with other options, eg. \"time:iso:utc\" or \"time:unix:usec\".\n"
+            "\tUse \"replay[:N]\" to replay file inputs at (N-times) realtime.\n"
             "\tUse \"protocol\" / \"noprotocol\" to output the decoder protocol number meta data.\n"
             "\tUse \"level\" to add Modulation, Frequency, RSSI, SNR, and Noise meta data.\n"
-            "\tUse \"noise[:secs]\" to report estimated noise level at intervals (default: 10 seconds).\n"
+            "\tUse \"noise[:<secs>]\" to report estimated noise level at intervals (default: 10 seconds).\n"
             "\tUse \"stats[:[<level>][:<interval>]]\" to report statistics (default: 600 seconds).\n"
             "\t  level 0: no report, 1: report successful devices, 2: report active devices, 3: report all\n"
             "\tUse \"bits\" to add bit representation to code outputs (for debug).\n");
@@ -326,6 +365,12 @@ static void sdr_callback(unsigned char *iq_buf, uint32_t len, void *ctx)
     char time_str[LOCAL_TIME_BUFLEN];
     unsigned long n_samples;
 
+    // do this here and not in sdr_handler so realtime replay can use rtl_tcp output
+    for (void **iter = cfg->raw_handler.elems; iter && *iter; ++iter) {
+        raw_output_t *output = *iter;
+        raw_output_frame(output, iq_buf, len);
+    }
+
     if ((cfg->bytes_to_read > 0) && (cfg->bytes_to_read <= len)) {
         len = cfg->bytes_to_read;
         cfg->exit_async = 1;
@@ -659,7 +704,7 @@ static void sdr_callback(unsigned char *iq_buf, uint32_t len, void *ctx)
     // choose hop_index as frequency_index, if there are too few hop_times use the last one
     int hop_index = cfg->hop_times > cfg->frequency_index ? cfg->frequency_index : cfg->hop_times - 1;
     if (cfg->hop_times > 0 && cfg->frequencies > 1
-            && difftime(rawtime, cfg->hop_start_time) > cfg->hop_time[hop_index]) {
+            && difftime(rawtime, cfg->hop_start_time) >= cfg->hop_time[hop_index]) {
         alarm(0); // cancel the watchdog timer
         cfg->hop_now = 1;
     }
@@ -699,7 +744,7 @@ static int hasopt(int test, int argc, char *argv[], char const *optstring)
 
 static void parse_conf_option(r_cfg_t *cfg, int opt, char *arg);
 
-#define OPTSTRING "hVvqDc:x:z:p:a:AI:S:m:M:r:w:W:l:d:t:f:H:g:s:b:n:R:X:F:K:C:T:UG:y:E:Y:"
+#define OPTSTRING "hVvqDc:x:z:p:a:AI:S:m:M:r:w:W:l:d:t:f:H:g:s:b:n:R:X:F:K:C:T:UGy:E:Y:"
 
 // these should match the short options exactly
 static struct conf_keywords const conf_keywords[] = {
@@ -855,15 +900,8 @@ static void parse_conf_option(r_cfg_t *cfg, int opt, char *arg)
             FATAL_STRDUP("parse_conf_option()");
         break;
     case 'G':
-        if (atobv(arg, 1) == 4) {
-            fprintf(stderr, "\n\tUse -G for testing only. Enable protocols with -R if you really need them.\n\n");
-            cfg->no_default_devices = 1;
-            register_all_protocols(cfg, 1);
-        }
-        else {
-            fprintf(stderr, "\n\tUse -G for testing only. Enable with -G 4 if you really mean it.\n\n");
-            exit(1);
-        }
+        fprintf(stderr, "register_all (-G) is deprecated. Use -R or a config file to enable additional protocols.\n");
+        exit(1);
         break;
     case 'p':
         cfg->ppm_error = atobv(arg, 0);
@@ -1013,13 +1051,15 @@ static void parse_conf_option(r_cfg_t *cfg, int opt, char *arg)
         else if (!strcasecmp(arg, "oldmodel"))
             fprintf(stderr, "oldmodel option (-M) is deprecated.\n");
         else if (!strncasecmp(arg, "stats", 5)) {
-            // there also should be options to set wether to flush on report
+            // there also should be options to set whether to flush on report
             char *p = arg_param(arg);
             cfg->report_stats = atoiv(p, 1);
             cfg->stats_interval = atoiv(arg_param(p), 600); // atoi_time_default()
             time(&cfg->stats_time);
             cfg->stats_time += cfg->stats_interval;
         }
+        else if (!strncasecmp(arg, "replay", 6))
+            cfg->in_replay = atobv(arg_param(arg), 1);
         else
             cfg->report_meta = atobv(arg, 1);
         break;
@@ -1094,12 +1134,18 @@ static void parse_conf_option(r_cfg_t *cfg, int opt, char *arg)
         else if (strncmp(arg, "syslog", 6) == 0) {
             add_syslog_output(cfg, arg_param(arg));
         }
-        else if (strncmp(optarg, "http", 4) == 0) {
-            add_http_output(cfg, arg_param(optarg));
+        else if (strncmp(arg, "http", 4) == 0) {
+            add_http_output(cfg, arg_param(arg));
+        }
+        else if (strncmp(arg, "trigger", 7) == 0) {
+            add_trigger_output(cfg, arg_param(arg));
         }
         else if (strncmp(arg, "null", 4) == 0) {
             add_null_output(cfg, arg_param(arg));
         }
+        else if (strncmp(arg, "rtl_tcp", 7) == 0) {
+            add_rtltcp_output(cfg, arg_param(arg));
+        }
         else {
             fprintf(stderr, "Invalid output format %s\n", arg);
             usage(1);
@@ -1201,23 +1247,27 @@ static r_cfg_t g_cfg;
 #define SIGINFO 29
 #endif
 
+// NOTE: printf is not async safe per signal-safety(7)
+// writes a static string, without the terminating zero, to stderr, ignores return value
+#define write_err(s) (void)!write(STDERR_FILENO, (s), sizeof(s) - 1)
+
 #ifdef _WIN32
 BOOL WINAPI
 console_handler(int signum)
 {
     if (CTRL_C_EVENT == signum) {
-        fprintf(stderr, "Signal caught, exiting!\n");
+        write_err("Signal caught, exiting!\n");
         g_cfg.exit_async = 1;
         sdr_stop(g_cfg.dev);
         return TRUE;
     }
     else if (CTRL_BREAK_EVENT == signum) {
-        fprintf(stderr, "CTRL-BREAK detected, hopping to next frequency (-f). Use CTRL-C to quit.\n");
+        write_err("CTRL-BREAK detected, hopping to next frequency (-f). Use CTRL-C to quit.\n");
         g_cfg.hop_now = 1;
         return TRUE;
     }
     else if (signum == SIGALRM) {
-        fprintf(stderr, "Async read stalled, exiting!\n");
+        write_err("Async read stalled, exiting!\n");
         g_cfg.exit_code = 3;
         g_cfg.exit_async = 1;
         sdr_stop(g_cfg.dev);
@@ -1248,11 +1298,11 @@ static void sighandler(int signum)
         return;
     }
     else if (signum == SIGALRM) {
-        fprintf(stderr, "Async read stalled, exiting!\n");
+        write_err("Async read stalled, exiting!\n");
         g_cfg.exit_code = 3;
     }
     else {
-        fprintf(stderr, "Signal caught, exiting!\n");
+        write_err("Signal caught, exiting!\n");
     }
     g_cfg.exit_async = 1;
     sdr_stop(g_cfg.dev);
@@ -1430,7 +1480,7 @@ int main(int argc, char **argv) {
 
     char const **well_known = well_known_output_fields(cfg);
     start_outputs(cfg, well_known);
-    free(well_known);
+    free((void *)well_known);
 
     if (cfg->out_block_size < MINIMAL_BUF_LENGTH ||
             cfg->out_block_size > MAXIMAL_BUF_LENGTH) {
@@ -1498,7 +1548,7 @@ int main(int argc, char **argv) {
                         r += run_fsk_demods(&single_dev, &pulse_data);
                     list_free_elems(&single_dev, NULL);
                 } else
-                r += pulse_demod_string(e, r_dev);
+                r += pulse_slicer_string(e, r_dev);
                 continue;
             }
             // otherwise test all decoders
@@ -1514,7 +1564,7 @@ int main(int argc, char **argv) {
                 r_device *r_dev = *iter;
                 if (cfg->verbosity)
                     fprintf(stderr, "Verifying test data with device %s.\n", r_dev->name);
-                r += pulse_demod_string(line, r_dev);
+                r += pulse_slicer_string(line, r_dev);
             }
         }
 
@@ -1540,7 +1590,7 @@ int main(int argc, char **argv) {
             r_device *r_dev = *iter;
             if (cfg->verbosity)
                 fprintf(stderr, "Verifying test data with device %s.\n", r_dev->name);
-            r += pulse_demod_string(cfg->test_data, r_dev);
+            r += pulse_slicer_string(cfg->test_data, r_dev);
         }
         r_free_cfg(cfg);
         exit(!r);
@@ -1640,7 +1690,17 @@ int main(int argc, char **argv) {
             // default case for file-inputs
             int n_blocks = 0;
             unsigned long n_read;
+            delay_timer_t delay_timer;
+            delay_timer_init(&delay_timer);
             do {
+                // Replay in realtime if requested
+                if (cfg->in_replay) {
+                    // per block delay
+                    unsigned delay_us = (unsigned)(1000000llu * DEFAULT_BUF_LENGTH / cfg->samp_rate / demod->sample_size / cfg->in_replay);
+                    if (demod->load_info.format == CF32_IQ)
+                        delay_us /= 2; // adjust for float only reading half as many samples
+                    delay_timer_wait(&delay_timer, delay_us);
+                }
                 // Convert CF32 file to CS16 buffer
                 if (demod->load_info.format == CF32_IQ) {
                     n_read = fread(test_mode_float_buf, sizeof(float), DEFAULT_BUF_LENGTH / 2, in_file);
