@@ -22,13 +22,22 @@
 #include "fatal.h"
 #ifdef RTLSDR
 #include <rtl-sdr.h>
+#if defined(__linux__) && (defined(__GNUC__) || defined(__clang__))
+// not available in rtlsdr 0.5.3, allow weak link for Linux
+int __attribute__((weak)) rtlsdr_set_bias_tee(rtlsdr_dev_t *dev, int on);
+#endif
+#ifdef LIBUSB1
 #include <libusb.h> /* libusb_error_name(), libusb_strerror() */
 #endif
+#endif
 #ifdef SOAPYSDR
 #include <SoapySDR/Version.h>
 #include <SoapySDR/Device.h>
 #include <SoapySDR/Formats.h>
 #include <SoapySDR/Logger.h>
+#if (SOAPY_SDR_API_VERSION < 0x00080000)
+#define SoapySDR_free(ptr) free(ptr)
+#endif
 #endif
 
 #ifndef _MSC_VER
@@ -86,10 +95,12 @@ struct sdr_dev {
 
     int running;
     int polling;
-    void *buffer;
-    size_t buffer_size;
+    uint8_t *buffer; ///< sdr data buffer current and past frames
+    size_t buffer_size; ///< sdr data buffer overall size (num * len)
+    size_t buffer_pos; ///< sdr data buffer next write position
 
     int sample_size;
+    int sample_signed;
 
     int apply_rate;
     int apply_freq;
@@ -157,14 +168,19 @@ struct rtl_tcp_info {
 };
 #pragma pack(pop)
 
-static int rtltcp_open(sdr_dev_t **out_dev, int *sample_size, char *dev_query, int verbose)
+static int rtltcp_open(sdr_dev_t **out_dev, char const *dev_query, int verbose)
 {
     UNUSED(verbose);
     char *host = "localhost";
     char *port = "1234";
+    char hostport[280]; // 253 chars DNS name plus extra chars
 
-    char *param = arg_param(dev_query);
-    hostport_param(param, &host, &port);
+    char *param = arg_param(dev_query); // strip scheme
+    hostport[0] = '\0';
+    if (param)
+        strncpy(hostport, param, sizeof(hostport) - 1);
+    hostport[sizeof(hostport) - 1] = '\0';
+    hostport_param(hostport, &host, &port);
 
     fprintf(stderr, "rtl_tcp input from %s port %s\n", host, port);
 
@@ -243,8 +259,8 @@ static int rtltcp_open(sdr_dev_t **out_dev, int *sample_size, char *dev_query, i
     }
 
     dev->rtl_tcp = sock;
-    dev->sample_size = sizeof(uint8_t); // CU8
-    *sample_size = sizeof(uint8_t); // CU8
+    dev->sample_size = sizeof(uint8_t) * 2; // CU8
+    dev->sample_signed = 0;
 
     *out_dev = dev;
     return 0;
@@ -269,20 +285,25 @@ static int rtltcp_close(SOCKET sock)
 
 static int rtltcp_read_loop(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint32_t buf_num, uint32_t buf_len)
 {
-    UNUSED(buf_num);
-    if (dev->buffer_size != buf_len) {
+    size_t buffer_size = buf_num * buf_len;
+    if (dev->buffer_size != buffer_size) {
         free(dev->buffer);
-        dev->buffer = malloc(buf_len);
+        dev->buffer = malloc(buffer_size);
         if (!dev->buffer) {
             WARN_MALLOC("rtltcp_read_loop()");
             return -1; // NOTE: returns error on alloc failure.
         }
-        dev->buffer_size = buf_len;
+        dev->buffer_size = buffer_size;
+        dev->buffer_pos = 0;
     }
-    uint8_t *buffer = dev->buffer;
 
     dev->running = 1;
     do {
+        if (dev->buffer_pos + buf_len > buffer_size)
+            dev->buffer_pos = 0;
+        uint8_t *buffer = &dev->buffer[dev->buffer_pos];
+        dev->buffer_pos += buf_len;
+
         unsigned n_read = 0;
         int r;
 
@@ -355,7 +376,7 @@ static int rtltcp_command(sdr_dev_t *dev, char cmd, int param)
 
 #ifdef RTLSDR
 
-static int sdr_open_rtl(sdr_dev_t **out_dev, int *sample_size, char *dev_query, int verbose)
+static int sdr_open_rtl(sdr_dev_t **out_dev, char const *dev_query, int verbose)
 {
     uint32_t device_count = rtlsdr_get_device_count();
     if (!device_count) {
@@ -416,8 +437,8 @@ static int sdr_open_rtl(sdr_dev_t **out_dev, int *sample_size, char *dev_query,
             if (verbose)
                 fprintf(stderr, "Using device %u: %s\n",
                         i, rtlsdr_get_device_name(i));
-            dev->sample_size = sizeof(uint8_t); // CU8
-            *sample_size = sizeof(uint8_t); // CU8
+            dev->sample_size = sizeof(uint8_t) * 2; // CU8
+            dev->sample_signed = 0;
 
             size_t info_len = 41 + strlen(vendor) + strlen(product) + strlen(serial);
             dev->dev_info = malloc(info_len);
@@ -478,18 +499,38 @@ static int rtlsdr_find_tuner_gain(sdr_dev_t *dev, int centigain, int verbose)
 static void rtlsdr_read_cb(unsigned char *iq_buf, uint32_t len, void *ctx)
 {
     sdr_dev_t *dev = ctx;
+
+    if (dev->buffer_pos + len > dev->buffer_size)
+        dev->buffer_pos = 0;
+    uint8_t *buffer = &dev->buffer[dev->buffer_pos];
+    dev->buffer_pos += len;
+
+    // NOTE: we need to copy the buffer, it might go away on cancel_async
+    memcpy(buffer, iq_buf, len);
+
     sdr_event_t ev = {
             .ev  = SDR_EV_DATA,
-            .buf = iq_buf,
+            .buf = buffer,
             .len = len,
     };
     if (len > 0) // prevent a crash in callback
         dev->rtlsdr_cb(&ev, dev->rtlsdr_cb_ctx);
-    // NOTE: we actually need to copy the buffer to prevent it going away on cancel_async
 }
 
 static int rtlsdr_read_loop(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint32_t buf_num, uint32_t buf_len)
 {
+    size_t buffer_size = buf_num * buf_len;
+    if (dev->buffer_size != buffer_size) {
+        free(dev->buffer);
+        dev->buffer = malloc(buffer_size);
+        if (!dev->buffer) {
+            WARN_MALLOC("rtlsdr_read_loop()");
+            return -1; // NOTE: returns error on alloc failure.
+        }
+        dev->buffer_size = buffer_size;
+        dev->buffer_pos = 0;
+    }
+
     int r = 0;
 
     dev->rtlsdr_cb = cb;
@@ -508,9 +549,16 @@ static int rtlsdr_read_loop(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint32
         //     r = libusb_cancel_transfer(dev->xfer[i]);
         // We can safely assume it's an libusb error.
         if (r < 0) {
+#ifdef LIBUSB1
             fprintf(stderr, "\n%s: %s!\n"
                             "Check your RTL-SDR dongle, USB cables, and power supply.\n\n",
                     libusb_error_name(r), libusb_strerror(r));
+#else
+            fprintf(stderr, "\nLIBUSB_ERROR: %d\n"
+                            "Check your RTL-SDR dongle, USB cables, and power supply.\n\n",
+                    r);
+#endif
+            dev->running = 0;
         }
         dev->polling = 0;
         apply_changes(dev, cb, ctx);
@@ -575,7 +623,7 @@ static int soapysdr_direct_sampling(SoapySDRDevice *dev, int on)
         fprintf(stderr, "Enabled direct sampling mode, input 2/Q.\n");}
     else if (set_num == 3) {
         fprintf(stderr, "Enabled no-mod direct sampling mode.\n");}
-    free(set_value);
+    SoapySDR_free(set_value);
     return r;
 }
 
@@ -598,7 +646,7 @@ static int soapysdr_offset_tuning(SoapySDRDevice *dev)
     else {
         fprintf(stderr, "Offset tuning mode enabled.\n");
     }
-    free(set_value);
+    SoapySDR_free(set_value);
     return r;
 }
 
@@ -639,7 +687,7 @@ static int soapysdr_auto_gain(SoapySDRDevice *dev, int verbose)
         }
 
     }
-    free(driver);
+    SoapySDR_free(driver);
     // otherwise leave unset, hopefully the driver has good defaults
 
     return r;
@@ -731,7 +779,7 @@ static void soapysdr_show_device_info(SoapySDRDevice *dev)
 
     hwkey = SoapySDRDevice_getHardwareKey(dev);
     fprintf(stderr, "Using device %s: ", hwkey);
-    free(hwkey);
+    SoapySDR_free(hwkey);
 
     args = SoapySDRDevice_getHardwareInfo(dev);
     for (i = 0; i < args.size; ++i) {
@@ -771,7 +819,7 @@ static void soapysdr_show_device_info(SoapySDRDevice *dev)
         fprintf(stderr, "%.0f - %.0f (step %.0f) ", frequencyRanges[i].minimum, frequencyRanges[i].maximum, frequencyRanges[i].step);
     }
     fprintf(stderr, "\n");
-    free(frequencyRanges);
+    SoapySDR_free(frequencyRanges);
 
     rates = SoapySDRDevice_getSampleRateRange(dev, direction, channel, &len);
     fprintf(stderr, "Found %zu sample rate range(s): ", len);
@@ -782,7 +830,7 @@ static void soapysdr_show_device_info(SoapySDRDevice *dev)
             fprintf(stderr, "%.0f - %.0f (step %.0f) ", rates[i].minimum, rates[i].maximum, rates[i].step);
     }
     fprintf(stderr, "\n");
-    free(rates);
+    SoapySDR_free(rates);
 
     bandwidths = SoapySDRDevice_getBandwidthRange(dev, direction, channel, &len);
     fprintf(stderr, "Found %zu bandwidth range(s): ", len);
@@ -790,7 +838,7 @@ static void soapysdr_show_device_info(SoapySDRDevice *dev)
         fprintf(stderr, "%.0f - %.0f (step %.0f) ", bandwidths[i].minimum, bandwidths[i].maximum, bandwidths[i].step);
     }
     fprintf(stderr, "\n");
-    free(bandwidths);
+    SoapySDR_free(bandwidths);
 
     double bandwidth = SoapySDRDevice_getBandwidth(dev, direction, channel);
     fprintf(stderr, "Found current bandwidth %.0f\n", bandwidth);
@@ -805,10 +853,10 @@ static void soapysdr_show_device_info(SoapySDRDevice *dev)
 
     native_stream_format = SoapySDRDevice_getNativeStreamFormat(dev, direction, channel, &fullScale);
     fprintf(stderr, "Found native stream format: %s (full scale: %.1f)\n", native_stream_format, fullScale);
-    free(native_stream_format);
+    SoapySDR_free(native_stream_format);
 }
 
-static int sdr_open_soapy(sdr_dev_t **out_dev, int *sample_size, char *dev_query, int verbose)
+static int sdr_open_soapy(sdr_dev_t **out_dev, char const *dev_query, int verbose)
 {
     if (verbose)
         SoapySDR_setLogLevel(SOAPY_SDR_DEBUG);
@@ -837,28 +885,31 @@ static int sdr_open_soapy(sdr_dev_t **out_dev, int *sample_size, char *dev_query
     if (!strcmp(SOAPY_SDR_CU8, native_format)) {
         // actually not supported by SoapySDR
         selected_format = SOAPY_SDR_CU8;
-        *sample_size = sizeof(uint8_t); // CU8
+        dev->sample_size = sizeof(uint8_t); // CU8
+        dev->sample_signed = 0;
     }
 //    else if (!strcmp(SOAPY_SDR_CS8, native_format)) {
 //        // TODO: CS8 needs conversion to CU8
 //        // e.g. RTL-SDR (8 bit), scale is 128.0
 //        selected_format = SOAPY_SDR_CS8;
-//        *sample_size = sizeof(int8_t); // CS8
+//        dev->sample_size = sizeof(int8_t) * 2; // CS8
+//        dev->sample_signed = 1;
 //    }
     else if (!strcmp(SOAPY_SDR_CS16, native_format)) {
         // e.g. LimeSDR-mini (12 bit), native scale is 2048.0
         // e.g. SDRplay RSP1A (14 bit), native scale is 32767.0
         selected_format = SOAPY_SDR_CS16;
-        *sample_size = sizeof(int16_t); // CS16
+        dev->sample_size = sizeof(int16_t) * 2; // CS16
+        dev->sample_signed = 1;
     }
     else {
         // force CS16
         selected_format = SOAPY_SDR_CS16;
-        *sample_size = sizeof(int16_t); // CS16
+        dev->sample_size = sizeof(int16_t) * 2; // CS16
+        dev->sample_signed = 1;
         dev->fullScale = 32768.0; // assume max for SOAPY_SDR_CS16
     }
-    dev->sample_size = *sample_size;
-    free(native_format);
+    SoapySDR_free(native_format);
 
     SoapySDRKwargs args = SoapySDRDevice_getHardwareInfo(dev->soapy_dev);
     size_t info_len     = 2;
@@ -872,6 +923,7 @@ static int sdr_open_soapy(sdr_dev_t **out_dev, int *sample_size, char *dev_query
         p += sprintf(p, "%s\"%s\":\"%s\"", i ? "," : "{", args.keys[i], args.vals[i]);
     }
     sprintf(p, "}");
+    SoapySDRKwargs_clear(&args);
 
     SoapySDRKwargs stream_args = {0};
     int r;
@@ -897,22 +949,27 @@ static int sdr_open_soapy(sdr_dev_t **out_dev, int *sample_size, char *dev_query
 
 static int soapysdr_read_loop(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint32_t buf_num, uint32_t buf_len)
 {
-    UNUSED(buf_num);
-    if (dev->buffer_size != buf_len) {
+    size_t buffer_size = buf_num * buf_len;
+    if (dev->buffer_size != buffer_size) {
         free(dev->buffer);
-        dev->buffer = malloc(buf_len);
+        dev->buffer = malloc(buffer_size);
         if (!dev->buffer) {
-            WARN_CALLOC("soapysdr_read_loop()");
+            WARN_MALLOC("soapysdr_read_loop()");
             return -1; // NOTE: returns error on alloc failure.
         }
-        dev->buffer_size = buf_len;
+        dev->buffer_size = buffer_size;
+        dev->buffer_pos = 0;
     }
-    int16_t *buffer = dev->buffer;
 
-    size_t buf_elems = buf_len / 2 / dev->sample_size;
+    size_t buf_elems = buf_len / dev->sample_size;
 
     dev->running = 1;
     do {
+        if (dev->buffer_pos + buf_len > buffer_size)
+            dev->buffer_pos = 0;
+        int16_t *buffer = (void *)&dev->buffer[dev->buffer_pos];
+        dev->buffer_pos += buf_len;
+
         void *buffs[]    = {buffer};
         int flags        = 0;
         long long timeNs = 0;
@@ -928,7 +985,7 @@ static int soapysdr_read_loop(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint
             n_read += r; // r is number of elements read, elements=complex pairs, so buffer length is twice
             //fprintf(stderr, "readStream ret=%d, flags=%d, timeNs=%lld (%zu - %u)\n", r, flags, timeNs, buf_elems, n_read);
         } while (n_read < buf_elems);
-        //fprintf(stderr, "readStream ret=%d (%d), flags=%d, timeNs=%lld\n", n_read, buf_len, flags, timeNs);
+        //fprintf(stderr, "readStream ret=%u (%u), flags=%d, timeNs=%lld\n", n_read, buf_len, flags, timeNs);
         if (r < 0) {
             if (r == SOAPY_SDR_OVERFLOW) {
                 fprintf(stderr, "O");
@@ -943,6 +1000,7 @@ static int soapysdr_read_loop(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint
         //for (i = 0; i < n_read * 2; ++i)
         //    cu8buf[i] = (int8_t)cu8buf[i] + 128;
 
+        // TODO: SoapyRemote doesn't scale properly when reading (local) CS16 from (remote) CS8
         // rescale cs16 buffer
         if (dev->fullScale >= 2047.0 && dev->fullScale <= 2048.0) {
             for (i = 0; i < n_read * 2; ++i)
@@ -957,7 +1015,7 @@ static int soapysdr_read_loop(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint
         sdr_event_t ev = {
                 .ev  = SDR_EV_DATA,
                 .buf = buffer,
-                .len = n_read * 2 * dev->sample_size,
+                .len = n_read * dev->sample_size,
         };
         dev->polling = 1;
         if (n_read > 0) // prevent a crash in callback
@@ -974,10 +1032,10 @@ static int soapysdr_read_loop(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint
 
 /* Public API */
 
-int sdr_open(sdr_dev_t **out_dev, int *sample_size, char *dev_query, int verbose)
+int sdr_open(sdr_dev_t **out_dev, char const *dev_query, int verbose)
 {
     if (dev_query && !strncmp(dev_query, "rtl_tcp", 7))
-        return rtltcp_open(out_dev, sample_size, dev_query, verbose);
+        return rtltcp_open(out_dev, dev_query, verbose);
 
 #if !defined(RTLSDR) && !defined(SOAPYSDR)
     if (verbose)
@@ -988,7 +1046,7 @@ int sdr_open(sdr_dev_t **out_dev, int *sample_size, char *dev_query, int verbose
     /* Open RTLSDR by default or if index or serial given, if available */
     if (!dev_query || *dev_query == ':' || (*dev_query >= '0' && *dev_query <= '9')) {
 #ifdef RTLSDR
-        return sdr_open_rtl(out_dev, sample_size, dev_query, verbose);
+        return sdr_open_rtl(out_dev, dev_query, verbose);
 #else
         fprintf(stderr, "No input driver for RTL-SDR compiled in.\n");
         return -1;
@@ -1001,8 +1059,9 @@ int sdr_open(sdr_dev_t **out_dev, int *sample_size, char *dev_query, int verbose
     UNUSED(soapysdr_offset_tuning);
 
     /* Open SoapySDR otherwise, if available */
-    return sdr_open_soapy(out_dev, sample_size, dev_query, verbose);
+    return sdr_open_soapy(out_dev, dev_query, verbose);
 #endif
+    fprintf(stderr, "No input driver for SoapySDR compiled in.\n");
 
     return -1;
 }
@@ -1041,6 +1100,22 @@ char const *sdr_get_dev_info(sdr_dev_t *dev)
     return dev->dev_info;
 }
 
+int sdr_get_sample_size(sdr_dev_t *dev)
+{
+    if (!dev)
+        return 0;
+
+    return dev->sample_size;
+}
+
+int sdr_get_sample_signed(sdr_dev_t *dev)
+{
+    if (!dev)
+        return 0;
+
+    return dev->sample_signed;
+}
+
 int sdr_set_center_freq(sdr_dev_t *dev, uint32_t freq, int verbose)
 {
     if (!dev)
@@ -1094,7 +1169,7 @@ uint32_t sdr_get_center_freq(sdr_dev_t *dev)
 
 #ifdef SOAPYSDR
     if (dev->soapy_dev)
-        return (int)SoapySDRDevice_getFrequency(dev->soapy_dev, SOAPY_SDR_RX, 0);
+        return (uint32_t)SoapySDRDevice_getFrequency(dev->soapy_dev, SOAPY_SDR_RX, 0);
 #endif
 
 #ifdef RTLSDR
@@ -1131,8 +1206,11 @@ int sdr_set_freq_correction(sdr_dev_t *dev, int ppm, int verbose)
 #endif
 
 #ifdef RTLSDR
-    if (dev->rtlsdr_dev)
+    if (dev->rtlsdr_dev) {
         r = rtlsdr_set_freq_correction(dev->rtlsdr_dev, ppm);
+        if (r == -2)
+            r = 0; // -2 is not an error code
+    }
 #endif
 
     if (verbose) {
@@ -1337,7 +1415,7 @@ uint32_t sdr_get_sample_rate(sdr_dev_t *dev)
 
 #ifdef SOAPYSDR
     if (dev->soapy_dev)
-        return (int)SoapySDRDevice_getSampleRate(dev->soapy_dev, SOAPY_SDR_RX, 0);
+        return (uint32_t)SoapySDRDevice_getSampleRate(dev->soapy_dev, SOAPY_SDR_RX, 0);
 #endif
 
 #ifdef RTLSDR
@@ -1354,50 +1432,114 @@ int sdr_apply_settings(sdr_dev_t *dev, char const *sdr_settings, int verbose)
         return -1;
 
     POSSIBLY_UNUSED(verbose);
-    int r = -1;
+    int r = 0;
 
     if (!sdr_settings || !*sdr_settings)
         return 0;
 
-#ifdef SOAPYSDR
-    if (!dev->soapy_dev) {
-        fprintf(stderr, "WARNING: sdr settings only available for SoapySDR devices.\n");
-        return -1;
+    if (dev->rtl_tcp) {
+        while (sdr_settings && *sdr_settings) {
+            char const *val = NULL;
+            // This mirrors the settings of SoapyRTLSDR
+            if (kwargs_match(sdr_settings, "direct_samp", &val)) {
+                int direct_sampling = atoiv(val, 1);
+                r = rtltcp_command(dev, RTLTCP_SET_DIRECT_SAMPLING, direct_sampling);
+            }
+            else if (kwargs_match(sdr_settings, "offset_tune", &val)) {
+                int offset_tuning = atobv(val, 1);
+                r = rtltcp_command(dev, RTLTCP_SET_OFFSET_TUNING, offset_tuning);
+            }
+            else if (kwargs_match(sdr_settings, "digital_agc", &val)) {
+                int digital_agc = atobv(val, 1);
+                r = rtltcp_command(dev, RTLTCP_SET_AGC_MODE, digital_agc);
+            }
+            else if (kwargs_match(sdr_settings, "biastee", &val)) {
+                int biastee = atobv(val, 1);
+                r = rtltcp_command(dev, RTLTCP_SET_BIAS_TEE, biastee);
+            }
+            else {
+                fprintf(stderr, "Unknown rtl_tcp setting: %s\n", sdr_settings);
+                return -1;
+            }
+            sdr_settings = kwargs_skip(sdr_settings);
+        }
+        return r;
     }
 
-    SoapySDRKwargs settings = SoapySDRKwargs_fromString(sdr_settings);
-    for (size_t i = 0; i < settings.size; ++i) {
-        const char *key   = settings.keys[i];
-        const char *value = settings.vals[i];
-        if (verbose)
-            fprintf(stderr, "Setting %s to %s\n", key, value);
-        if (!strcmp(key, "antenna")) {
-            if (SoapySDRDevice_setAntenna(dev->soapy_dev, SOAPY_SDR_RX, 0, value) != 0) {
-                r = -1;
-                fprintf(stderr, "WARNING: Antenna setting failed: %s\n", SoapySDRDevice_lastError());
+#ifdef SOAPYSDR
+    if (dev->soapy_dev) {
+        SoapySDRKwargs settings = SoapySDRKwargs_fromString(sdr_settings);
+        for (size_t i = 0; i < settings.size; ++i) {
+            const char *key   = settings.keys[i];
+            const char *value = settings.vals[i];
+            if (verbose)
+                fprintf(stderr, "Setting %s to %s\n", key, value);
+            if (!strcmp(key, "antenna")) {
+                if (SoapySDRDevice_setAntenna(dev->soapy_dev, SOAPY_SDR_RX, 0, value) != 0) {
+                    r = -1;
+                    fprintf(stderr, "WARNING: Antenna setting failed: %s\n", SoapySDRDevice_lastError());
+                }
             }
-        }
-        else if (!strcmp(key, "bandwidth")) {
-            uint32_t f_value = atouint32_metric(value, "-t bandwidth= ");
-            if (SoapySDRDevice_setBandwidth(dev->soapy_dev, SOAPY_SDR_RX, 0, (double)f_value) != 0) {
-                r = -1;
-                fprintf(stderr, "WARNING: Bandwidth setting failed: %s\n", SoapySDRDevice_lastError());
+            else if (!strcmp(key, "bandwidth")) {
+                uint32_t f_value = atouint32_metric(value, "-t bandwidth= ");
+                if (SoapySDRDevice_setBandwidth(dev->soapy_dev, SOAPY_SDR_RX, 0, (double)f_value) != 0) {
+                    r = -1;
+                    fprintf(stderr, "WARNING: Bandwidth setting failed: %s\n", SoapySDRDevice_lastError());
+                }
             }
-        }
-        else {
-            if (SoapySDRDevice_writeSetting(dev->soapy_dev, key, value) != 0) {
-                r = -1;
-                fprintf(stderr, "WARNING: sdr setting failed: %s\n", SoapySDRDevice_lastError());
+            else {
+                if (SoapySDRDevice_writeSetting(dev->soapy_dev, key, value) != 0) {
+                    r = -1;
+                    fprintf(stderr, "WARNING: sdr setting failed: %s\n", SoapySDRDevice_lastError());
+                }
             }
         }
+        SoapySDRKwargs_clear(&settings);
+        return r;
     }
-    SoapySDRKwargs_clear(&settings);
-    return r;
 #endif
 
-    fprintf(stderr, "WARNING: sdr settings only available for SoapySDR devices.\n");
+#ifdef RTLSDR
+    if (dev->rtlsdr_dev) {
+        while (sdr_settings && *sdr_settings) {
+            char const *val = NULL;
+            // This mirrors the settings of SoapyRTLSDR
+            if (kwargs_match(sdr_settings, "direct_samp", &val)) {
+                int direct_sampling = atoiv(val, 1);
+                r = rtlsdr_set_direct_sampling(dev->rtlsdr_dev, direct_sampling);
+            }
+            else if (kwargs_match(sdr_settings, "offset_tune", &val)) {
+                int offset_tuning = atobv(val, 1);
+                r = rtlsdr_set_offset_tuning(dev->rtlsdr_dev, offset_tuning);
+            }
+            else if (kwargs_match(sdr_settings, "digital_agc", &val)) {
+                int digital_agc = atobv(val, 1);
+                r = rtlsdr_set_agc_mode(dev->rtlsdr_dev, digital_agc);
+            }
+            else if (kwargs_match(sdr_settings, "biastee", &val)) {
+#if defined(__linux__) && (defined(__GNUC__) || defined(__clang__))
+                // check weak link for Linux with older rtlsdr
+                if (!rtlsdr_set_bias_tee) {
+                    fprintf(stderr, "This librtlsdr version does not support biastee setting\n");
+                    return -1;
+                }
+#endif
+                int biastee = atobv(val, 1);
+                r = rtlsdr_set_bias_tee(dev->rtlsdr_dev, biastee);
+            }
+            else {
+                fprintf(stderr, "Unknown RTLSDR setting: %s\n", sdr_settings);
+                return -1;
+            }
+            sdr_settings = kwargs_skip(sdr_settings);
+        }
+        return r;
+    }
+#endif
 
-    return r;
+    fprintf(stderr, "WARNING: sdr settings not available.\n"); // no open device
+
+    return -1;
 }
 
 int sdr_activate(sdr_dev_t *dev)
@@ -1456,6 +1598,11 @@ int sdr_start(sdr_dev_t *dev, sdr_event_cb_t cb, void *ctx, uint32_t buf_num, ui
     if (!dev)
         return -1;
 
+    if (buf_num == 0)
+        buf_num = SDR_DEFAULT_BUF_NUMBER;
+    if (buf_len == 0)
+        buf_len = SDR_DEFAULT_BUF_LENGTH;
+
     if (dev->rtl_tcp)
         return rtltcp_read_loop(dev, cb, ctx, buf_num, buf_len);
 
